﻿using Hotline.Orders;
using Hotline.Settings;
using Hotline.Settings.TimeLimitDomain;
using Hotline.Settings.TimeLimitDomain.Repository;
using Hotline.Share.Dtos.Settings;
using Hotline.Share.Enums.FlowEngine;
using Hotline.Share.Enums.Settings;
using Mapster;
using Shouldly;
using XF.Domain.Repository;

namespace Hotline.Application.Tests.Domain;
public class ZiGongExpireTimeTest
{
    private readonly ZiGongExpireTimeLimit _ziGongExpireTimeLimit;
    private readonly IRepository<Order> _orderRepository;
    private readonly ITimeLimitSettingAttributeRepository _timeLimitSettingAttributeRepository;
    private readonly ITimeLimitSettingInventoryRepository _timeLimitSettingInventoryRepository;

    public ZiGongExpireTimeTest(ZiGongExpireTimeLimit ziGongExpireTimeLimit, IRepository<Order> orderRepository, ITimeLimitSettingAttributeRepository timeLimitSettingAttributeRepository, ITimeLimitSettingInventoryRepository timeLimitSettingInventoryRepository)
    {
        _ziGongExpireTimeLimit = ziGongExpireTimeLimit;
        _orderRepository = orderRepository;
        _timeLimitSettingAttributeRepository = timeLimitSettingAttributeRepository;
        _timeLimitSettingInventoryRepository = timeLimitSettingInventoryRepository;
    }

    //[Theory]
    //// 24小时件
    //[InlineData("24小时件", "2024-09-04 14:00:00", "CenterToOrg", "08dccc8f-37b0-40d8-8112-1afb2230c5a3", "2024-09-05 14:00:00")]
    //// 疫情件
    //[InlineData("疫情件", "2024-09-05 14:01:01", "CenterToOrg", "08dccd5c-9bda-4e7d-8d63-82039dcfbde7", "2024-09-09 14:01:01")]
    //public async Task CalcExpiredTime_Test(string tip, string beginTxt, string flowTxt, string orderId, string expected)
    //{
    //    var beginTime = DateTime.Parse(beginTxt);
    //    if (orderId.Equals("08dccc8f-37b0-40d8-8112-1afb2230c5a3"))
    //        await InitOrderData(orderId);
    //    var order = await _orderRepository.Queryable().Where(m => m.Id == orderId).FirstAsync();
    //    Enum.TryParse(flowTxt, out EFlowDirection flow);
    //    var time = await _ziGongExpireTimeLimit.CalcExpiredTime(beginTime, flow, order.Adapt<OrderTimeClacInfo>());
    //    time.ShouldNotBeNull();
    //    time.ExpiredTime.ShouldBe(DateTime.Parse(expected), $"{tip} 期满时间错误");
    //}

    [Theory]
    [InlineData("企业咨询件单元测试", "2024-09-04 14:00:00", "CenterToOrg", "2024-09-05 14:00:00")]
    [InlineData("企业建议件单元测试", "2024-09-05 14:00:00", "CenterToOrg", "2024-09-09 14:00:00")]
    [InlineData("企业求助件单元测试", "2024-09-05 14:00:00", "CenterToOrg", "2024-09-09 14:00:00")]
    [InlineData("企业表扬件单元测试", "2024-09-05 14:00:00", "CenterToOrg", "2024-09-09 14:00:00")]
    [InlineData("企业举报件单元测试", "2024-09-05 14:00:00", "CenterToOrg", "2024-09-09 14:00:00")]
    [InlineData("企业投诉件单元测试", "2024-09-05 14:00:00", "CenterToOrg", "2024-09-09 14:00:00")]
    [InlineData("四川省12345咨询件单元测试", "2024-09-05 14:00:00", "CenterToOrg", "2024-09-06 14:00:00")]
    [InlineData("四川省12345建议件单元测试", "2024-09-05 14:00:00", "CenterToOrg", "2024-09-10 14:00:00")]
    [InlineData("中心到中心24小时", "2024-09-12 14:00:00", "CenterToCenter", "2024-09-13 14:00:00")]
    public async Task CalcExpiredTime_Test(string title, string beginTxt, string flowTxt, string expected)
    {
        var beginTime = DateTime.Parse(beginTxt);
        var order = await _orderRepository.Queryable().Where(m => m.Title == title).FirstAsync();
        order.ShouldNotBeNull($"{title} 测试数据不存在");
        Enum.TryParse(flowTxt, out EFlowDirection flow);
        var time = await _ziGongExpireTimeLimit.CalcExpiredTime(beginTime, flow, order.Adapt<OrderTimeClacInfo>());
        time.ShouldNotBeNull();
        time.ExpiredTime.ShouldBe(DateTime.Parse(expected), $"{title} 期满时间错误 AcceptTypeCode:{order.AcceptTypeCode}");
        time.TimeText.ShouldBe(order.Content, $"{title} 内容结果比对失败 AcceptTypeCode:{order.AcceptTypeCode}");
    }

    [Theory]
    [InlineData("求助三个工作日", "2024-09-12 22:01:28", "CenterToOrg", "2024-09-20 08:30:00")]
    public async Task CalcExpiredTime_Release_Test(string title, string beginTxt, string flowTxt, string expected)
    {
        var beginTime = DateTime.Parse(beginTxt);
        var order = await _orderRepository.Queryable().Where(m => m.Title == title).FirstAsync();
        order.ShouldNotBeNull($"{title} 测试数据不存在");
        Enum.TryParse(flowTxt, out EFlowDirection flow);
        var time = await _ziGongExpireTimeLimit.CalcExpiredTime(beginTime, flow, order.Adapt<OrderTimeClacInfo>());
        time.ShouldNotBeNull();
        time.ExpiredTime.ShouldBe(DateTime.Parse(expected), $"{title} 期满时间错误 AcceptTypeCode:{order.AcceptTypeCode}");
    }

    public async Task InitOrderData(string orderId)
    {
        var order = await _orderRepository.Queryable().Where(m => m.Id == orderId).FirstAsync();
        if (order.Is24HoursComplete) return;
        order.Is24HoursComplete = true;
        await _orderRepository.UpdateAsync(order);
    }

    [Theory]
    [InlineData("", "Is24HoursComplete", "true", false)]
    [InlineData("", "HotspotSpliceName", "疫情", false)]
    [InlineData("10", "IdentityType", "Enterprise", false)]
    [InlineData("15", "IdentityType", "Enterprise", false)]
    [InlineData("20", "IdentityType", "Enterprise", false)]
    public async Task InitTimeLimitData_Test(string busCode, string name, string value, bool isCommon)
    {
        var attributeEntity = new TimeLimitSettingAttribute { BusCode = busCode, Name = name, Value = value, IsCommon = isCommon };
        var dataEntity = await _timeLimitSettingAttributeRepository.GetAsync(attributeEntity.BusCode, attributeEntity.Name, attributeEntity.Value);
        if (dataEntity is null) await _timeLimitSettingAttributeRepository.AddAsync(attributeEntity);
    }

    [Theory]
    [InlineData("", "Is24HoursComplete", "true", "Hour", 24, "24小时件")]
    [InlineData("", "HotspotSpliceName", "疫情", "WorkDay", 2, "疫情类2个工作日")]
    [InlineData("10", "IdentityType", "Enterprise", "WorkDay", 1, "企业 '咨询' 件1个工作日")] 
    [InlineData("",   "IdentityType", "Enterprise", "WorkDay", 2, "企业 '非咨询' 件2个工作日")] 

    [InlineData("10", "SourceChannel", "四川省12345", "WorkDay", 1, "四川省12345 '咨询' 件1个工作日")] 
    [InlineData("", "SourceChannel", "四川省12345", "WorkDay", 3, "四川省12345 '非咨询' 件3个工作日")]

    [InlineData("10", "SourceChannel", "省政民互动", "WorkDay", 1, "省政民互动 '咨询' 件1个工作日")]
    [InlineData("", "SourceChannel", "省政民互动", "WorkDay", 3, "省政民互动 '非咨询' 件3个工作日")]

    [InlineData("10", "SourceChannel", "国家政务平台", "WorkDay", 1, "国家政务平台 '咨询' 件1个工作日")]
    [InlineData("", "SourceChannel", "国家政务平台", "WorkDay", 3, "国家政务平台 '非咨询' 件3个工作日")]

    [InlineData("10", "SourceChannel", "天府通办", "WorkDay", 1, "天府通办 '咨询' 件1个工作日")]
    [InlineData("", "SourceChannel", "天府通办", "WorkDay", 3, "天府通办 '非咨询' 件3个工作日")]

    [InlineData("10", "SourceChannel", "中国政府网", "WorkDay", 1, "中国政府网 '咨询' 件1个工作日")]
    [InlineData("", "SourceChannel", "中国政府网", "WorkDay", 3, "中国政府网 '非咨询' 件3个工作日")]
    public async Task InitTimeLimitInventory_Test(string busCode, string name, string value, string timeType, int timeValue, string remark)
    {
        var attributeEntity = new TimeLimitSettingAttribute { BusCode = busCode, Name = name, Value = value, IsCommon = false };
        var dataEntity = await _timeLimitSettingAttributeRepository.GetAsync(attributeEntity.BusCode, attributeEntity.Name, attributeEntity.Value);
        if (dataEntity is null) await _timeLimitSettingAttributeRepository.AddAsync(attributeEntity);

        var attribute = await _timeLimitSettingAttributeRepository.GetAsync(busCode, name, value);
        attribute.ShouldNotBeNull($"{name} 属性未初始化");
        Enum.TryParse(timeType, out ETimeType eTimeType);
        var entity = new TimeLimitSettingInventory { Code = attribute.Code.ToString(), TimeType = eTimeType, TimeValue = timeValue, Percentage = 80, PercentageOne = 50 , Remark = remark};
        var m = await _timeLimitSettingInventoryRepository.GetByCode(entity.Code);
        if (m is null) await _timeLimitSettingInventoryRepository.AddAsync(entity);
    }

}
