﻿
using Hotline.Share.Dtos.CallCenter;
using Hotline.Share.Dtos.Order;
using Hotline.Tools;
using MapsterMapper;
using Microsoft.AspNetCore.Mvc;
using MiniExcelLibs;
using XF.Domain.Dependency;

namespace Hotline.Application.ExportExcel
{
    public class ExportApplication : IExportApplication, IScopeDependency
    {
        private readonly IMapper _mapper;

        public ExportApplication(IMapper mapper)
        {
            _mapper = mapper;
        }

        /// <summary>
        /// 导出数据
        /// </summary>
        /// <typeparam name="T"></typeparam>
        /// <param name="list">数据集</param>
        /// <param name="name">导出文件名（不传则生成yyyyMMddhhmmss）</param>
        /// <returns></returns>
        public FileStreamResult ExportData<T>(List<T> list, string? name)
        {
            var stream = new MemoryStream();
            stream.SaveAs(list);
            stream.Seek(0, SeekOrigin.Begin);
            return new FileStreamResult(stream, "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet")
            {
                FileDownloadName = !string.IsNullOrEmpty(name) ? DateTime.Now.ToString("yyyyMMddhhmmss") + ".xlsx" : name
            };
        }

        public async Task<Stream> FittingAsync<T, D>(ExportExcelDto<D> dto, List<T> items, Action<List<T>>? action = null)
        {
            if (items != null && items.Count > 0)
            {
                action?.Invoke(items);
            }

            dynamic? dynamicClass = DynamicClassHelper.CreateDynamicClass(dto.ColumnInfos);

            var dtos = items
                .Select(stu => _mapper.Map(stu, typeof(BiCallDto), dynamicClass))
                .Cast<object>()
                .ToList();

            return ExcelHelper.CreateStream(dtos);
        }
    }
}
