﻿using Hotline.Caching.Interfaces;
using Hotline.Settings;
using Hotline.Share.Dtos.Order;
using Hotline.Share.Enums.Order;
using System;
using System.Collections.Concurrent;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Reflection;
using System.Text;
using System.Threading.Tasks;
using XF.Domain.Dependency;
using XF.Utility.EnumExtensions;

namespace Hotline.Application.Systems;
public class BaseDataApplication : IScopeDependency
{
    private readonly ISystemDicDataCacheManager _sysDicDataCacheManager;

    public BaseDataApplication(ISystemDicDataCacheManager sysDicDataCacheManager)
    {
        _sysDicDataCacheManager = sysDicDataCacheManager;
    }

    private ConcurrentDictionary<string, dynamic> _baseData = new ConcurrentDictionary<string, dynamic>();
    //private ConcurrentDictionary<string, int> _baseType = new ConcurrentDictionary<string, int>();
    //private ConcurrentDictionary<string, int> _enumType = new ConcurrentDictionary<string, int>();
    #region 内部方法
    private void Add(Type type)
    {
        var name = new StackTrace().GetFrame(1).GetMethod().Name;
        var method = typeof(EnumExts).GetMethod("GetDescriptions", BindingFlags.Static | BindingFlags.Public);
        var genericMethod = method.MakeGenericMethod(type);
        var result = genericMethod.Invoke(null, null);
        _baseData.TryAdd(name, result);
    }

    private void Add(string key)
    {
        var name = new StackTrace().GetFrame(1).GetMethod().Name;
        var result = _sysDicDataCacheManager
            .GetSysDicDataCache(key)
            .Where(x => x.DicDataValue != "-1")
            .Select(m => new { m.Id, m.DicDataName, m.DicDataValue });
        _baseData.TryAdd(name, result);
    }
    #endregion

    public BaseDataApplication Source()
    {
        Add(typeof(ESource));
        return this;
    }

    public BaseDataApplication VisitType()
    {
        Add(typeof(EVisitType));
        return this;
    }

    public Dictionary<string, dynamic> Build()
    {
        return new Dictionary<string, dynamic>(_baseData);
    }

    public BaseDataApplication VoiceEvaluate()
    {
        Add(typeof(EVoiceEvaluate));
        return this;
    }

    public BaseDataApplication SeatEvaluate()
    {
        Add(typeof(ESeatEvaluate));
        return this;
    }

    public BaseDataApplication VisitSatisfaction()
    {
        Add(SysDicTypeConsts.VisitSatisfaction);
        return this;
    }

    public BaseDataApplication VisitManner()
    {
        Add(SysDicTypeConsts.VisitManner);
        return this;
    }

    public BaseDataApplication VisitStateQuery()
    {
        Add(typeof(EVisitStateQuery));
        return this;
    }

    public BaseDataApplication DissatisfiedReason()
    {
        Add(SysDicTypeConsts.DissatisfiedReason);
        return this;
    }

    public BaseDataApplication CallForwardingSource()
    {
        Add(SysDicTypeConsts.CallForwardingSource);
        return this;
    }

    public BaseDataApplication CallForwardingType()
    {
        Add(SysDicTypeConsts.CallForwardingType);
        return this;
    }
}
