﻿using Hotline.Share.Enums.FlowEngine;
using System.ComponentModel;

namespace Hotline.Share.Dtos.FlowEngine;

/// <summary>
/// 办理参数
/// </summary>
public class NextWorkflowDto : BasicWorkflowDto
{
    public string WorkflowId { get; set; }

    /// <summary>
    /// 当前办理节点id
    /// </summary>
    public string StepId { get; set; }

    ///// <summary>
    ///// 下一节点到期时间(节点期满时间)
    ///// 需求调整
    ///// </summary>
    //public DateTime StepExpiredTime { get; set; }

    #region 手动填入办理人信息

    /// <summary>
    /// 真实办理人姓名（手动填写）
    /// </summary>
    public string? RealHandlerName { get; set; }

    /// <summary>
    /// 真实办理人电话（手动填写）
    /// </summary>
    public string? RealHandlerPhone { get; set; }

    /// <summary>
    /// 沟通方式（手动填写）
    /// </summary>
    public ERealCommunicationMode? RealCommunicationMode { get; set; }

    /// <summary>
    /// 沟通时间（手动填写）
    /// </summary>
    public DateTime? RealCommunicationTime { get; set; }

    /// <summary>
    /// 沟通地点（手动填写）
    /// </summary>
    public string? RealCommunicationAddress { get; set; }

    /// <summary>
    /// 已与市民沟通
    /// 已与市民电话联系，确认办理结果
    /// </summary>
    [Description("已与市民电话联系，确认办理结果")]
    public bool? RealIsContacted { get; set; }

    /// <summary>
    /// 已与市民现场沟通
    /// 已赴现场处置，将处理结果告知市民
    /// </summary>
    [Description("已赴现场处置，将处理结果告知市民")]
    public bool? RealContactLocale { get; set; }

    #endregion

    #region task_298
    /// <summary>
    /// 其它
    /// </summary>
    [Description("其它")]
    public bool? IsOther { get; set; }

    /// <summary>
    /// 其它原因
    /// </summary>
    [Description("其它原因")]
    public string? OtherRemark { get; set; }

    /// <summary>
    /// 是否紧急
    /// </summary>
    public bool? IsUrgent { get; set; }

    /// <summary>
    /// 是否推诿
    /// </summary>
    public bool? IsEvasive { get; set; }

    /// <summary>
    /// 是否不积极
    /// </summary>
    public bool? IsInactively { get; set; }

    /// <summary>
    /// 领导短信Key
    /// </summary>
    public string? LeaderSMSKey { get; set; }

    /// <summary>
    /// 是否市州转办
    /// </summary>
    public bool? Transpond { get; set; }

    /// <summary>
    /// 市州转办信息
    /// </summary>
    public string? TranspondCityName { get; set; }

    /// <summary>
    /// 市州转办信息
    /// </summary>
    public string? TranspondCityId { get; set; }

    /// <summary>
    /// 市州转办信息
    /// </summary>
    public string? TranspondCityValue { get; set; }

    #endregion
}