﻿using Newtonsoft.Json;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Reflection;
using System.Text;
using System.Threading.Tasks;

namespace Hotline.Share.Tools;
public static class ObjectExtensions
{
    /// <summary>
    /// 遍历类属性
    /// </summary>
    /// <typeparam name="T"></typeparam>
    /// <param name="model"></param>
    /// <param name="func">返回 true: contions; false: break</param>
    public static void ForeachClassProperties<T>(this T model, Func<T, PropertyInfo , string, object, Task<bool>> func)
    {
        var t = model.GetType();
        var propertyList = t.GetProperties();
        foreach (var item in propertyList)
        {
            var name = item.Name;
            var value = item.GetValue(model, null);
            var result = func(model, item, name, value).GetAwaiter().GetResult();
            if (result == false) break;
        }
    }

    /// <summary>
    /// 扩展方法用于手动验证对象，并返回验证结果。
    /// </summary>
    /// <param name="obj">需要验证的对象</param>
    /// <returns>如果验证成功返回 string.Empty，否则返回错误信息</returns>
    public static string ValidateObject(this object obj)
    {
        var validationResults = new List<ValidationResult>();
        var validationContext = new ValidationContext(obj);

        // 验证对象
        bool isValid = Validator.TryValidateObject(obj, validationContext, validationResults, true);

        if (isValid)
        {
            return string.Empty;
        }
        else
        {
            // 如果验证失败，返回所有错误信息的拼接
            return string.Join("; ", validationResults.Select(result => result.ErrorMessage));
        }
    }

    public static string ToJson(this object obj)
    {
        return JsonConvert.SerializeObject(obj);
    }
}
