﻿// Copyright (c) 2018 Jon P Smith, GitHub: JonPSmith, web: http://www.thereformedprogrammer.net/
// Licensed under MIT license. See License.txt in the project root for license information.

using System.ComponentModel.DataAnnotations;
using System.Diagnostics;

namespace Hotline.Permissions
{
    public enum EPermission
    {
        NotSet = 0, //error condition

        //Here is an example of very detailed control over something
        /// <summary>
        /// 首页
        /// </summary>
        [Display(GroupName = "首页", Name = "首页", Description = "首页")]
        Home = 000000,
        /// <summary>
        /// 坐席首页
        /// </summary>
        [Display(GroupName = "首页",Name ="坐席首页",Description = "坐席首席")]
        HomeSeat = 000001,
        /// <summary>
        /// 部门首页
        /// </summary>
        [Display(GroupName ="首页",Name ="部门首页",Description ="部门首页")]
        HomeOrg = 000002,
        #region 业务办理（10,00,00）
        /// <summary>
        /// 业务办理
        /// </summary>
        [Display(GroupName = "业务办理", Name = "业务办理",Description = "业务办理")]
        BusTodo = 100000,

        #region 工单坐席待办
        /// <summary>
        /// 工单坐席待办
        /// </summary>
        [Display(GroupName = "工单坐席待办",Name = "工单坐席待办",Description = "工单坐席待办")]
        OrderSeatTodo = 100100,

        /// <summary>
        /// 新建工单
        /// </summary>
        [Display(GroupName = "Order", Name = "新建工单", Description = "新建工单")]
        OrderAdd = 100101,
        /// <summary>
        /// 工单签收
        /// </summary>
        [Display(GroupName = "工单坐席待办",Name ="工单签收",Description ="工单签收")]
        OrderSign = 100102,
        /// <summary>
        /// 工单修改
        /// </summary>
        [Display(GroupName = "工单坐席待办",Name ="工单修改",Description ="工单修改")]
        OrderEdit = 100103,
        /// <summary>
        /// 交办单导出
        /// </summary>
        [Display(GroupName ="工单坐席待办",Name ="交办单导出",Description ="交办单导出")]
        JbdExport = 100104,
        #endregion

        #region 工单待办
        /// <summary>
        /// 工单待办
        /// </summary>
        [Display(GroupName = "工单待办",Name = "工单待办",Description = "工单待办")]
        OrderToDo = 100200,

        /// <summary>
        /// 省退回申请
        /// </summary>
        [Display(GroupName = "工单待办", Name = "退回申请", Description = "退回申请")]
        ApplySendBack = 100201,

        /// <summary>
        /// 交办单导出
        /// </summary>
        [Display(GroupName = "工单坐席待办", Name = "交办单导出", Description = "交办单导出")]
        ToDoOrderJbdExport = 100202,
        #endregion

        #region 工单受理
        /// <summary>
        /// 工单受理
        /// </summary>
        [Display(GroupName ="工单受理",Name ="工单受理",Description ="工单受理")]
        OrderAccept = 100300,

        #endregion

        #region 中心待办件
        /// <summary>
        /// 中心待办件
        /// </summary>
        [Display(GroupName ="中心待办件",Name ="中心待办件",Description ="中心待办件")]
        CenterToDo = 100400,
        /// <summary>
        /// 交办单导出
        /// </summary>
        [Display(GroupName ="中心待办件",Name = "交办单导出",Description ="交办单导出")]
        ToDoCenterJbdExport = 100401,
        /// <summary>
        /// 签收工单
        /// </summary>
        [Display(GroupName ="中心待办件",Name ="签收工单",Description ="签收工单")]
        ToDoCenterSign = 100402,
        /// <summary>
        /// 工单修改
        /// </summary>
        [Display(GroupName ="中心待办件",Name ="工单修改",Description ="工单修改")]
        ToDoCenterEdit = 100403,
        /// <summary>
        /// 中心待办件平级移动
        /// </summary>
        [Display(GroupName ="中心待办件",Name ="平级移动",Description ="平级移动")]
        ToDoCenterMigration = 100404,
        #endregion

        #endregion

        #region 业务管理（20,00,00）
        /// <summary>
        /// 业务管理
        /// </summary>
        [Display(GroupName = "业务管理",Name ="业务管理",Description = "业务管理")]
        BugManage = 200000,

        #region 综合查询
        /// <summary>
        /// 综合查询
        /// </summary>
        [Display(GroupName = "综合查询", Name = "综合查询", Description = "综合查询")]
        OrderList = 200100,

        /// <summary>
        /// 查询工单
        /// </summary>
        [Display(GroupName = "工单列表", Name = "查询工单列表", Description = "查询工单列表")]
        OrderQuery = 200101,

        /// <summary>
		/// 新增工单观察
		/// </summary>
		[Display(GroupName = "工单列表", Name = "新增工单观察", Description = "新增工单观察")]
        AddOrderObserve = 200102,

        /// <summary>
		/// 新增工单终结
		/// </summary>
		[Display(GroupName = "工单列表", Name = "新增工单终结", Description = "新增工单终结")]
        AddOrderFinality = 200103,

        /// <summary>
        /// 编辑工单
        /// </summary>
        [Display(GroupName = "工单列表", Name = "编辑工单", Description = "编辑工单")]
        OrderUpdate = 200104,
        /// <summary>
        /// 工单导出
        /// </summary>
        [Display(GroupName = "工单列表",Name ="工单导出",Description ="工单导出")]
        OrderExport = 200105,

        /// <summary>
        /// 工单延期
        /// </summary>
        [Display(GroupName = "工单列表", Name = "申请延期", Description = "申请延期")]
        ApplyDelay = 200106,
        /// <summary>
        /// 工单办理
        /// </summary>
        [Display(GroupName = "工单列表",Name ="工单办理",Description ="工单办理")]
        HandleOrder = 200107,

        /// <summary>
		/// 申请督办
		/// </summary>
		[Display(GroupName = "工单列表", Name = "申请督办", Description = "申请督办")]
        ApplySupervise = 200108,

        /// <summary>
		/// 申请催办
		/// </summary>
		[Display(GroupName = "工单列表", Name = "申请催办", Description = "申请催办")]
        ApplyUrge = 200109,
        /// <summary>
        /// 工单退回
        /// </summary>
        [Display(GroupName ="工单列表",Name ="工单退回",Description = "工单退回")]
        ReturnOrder = 200110,

        /// <summary>
		/// 特提申请
		/// </summary>
		[Display(GroupName = "工单列表", Name = "特提申请", Description = "特提申请")]
        ApplySpecial = 200111,
        /// <summary>
        /// 会签结束
        /// </summary>
        [Display(GroupName = "工单列表",Name ="会签结束",Description ="会签结束")]
        CloseCountersignature = 200112,
        /// <summary>
        /// 取消延期
        /// </summary>
        [Display(GroupName ="工单列表",Name = "取消延期",Description ="取消延期")]
        CancelOrderDelay = 200113,
        /// <summary>
        /// 批量省退回申请
        /// </summary>
        [Display(GroupName ="工单列表",Name ="批量省退回申请",Description ="批量省退回申请")]
        BatchProvinceBackApply = 200114,

        /// <summary>
        /// 工单签收
        /// </summary>
        [Display(GroupName = "工单列表",Name ="工单签收",Description ="工单签收")]
        OrderListSign = 200115,
        /// <summary>
        /// 交办单导出
        /// </summary>
        [Display(GroupName ="工单列表",Name ="交办单导出",Description ="交办单导出")]
        BusinessOrderJbdExport = 200116,

        /// <summary>
        /// 工单待办
        /// </summary>
        [Display(GroupName ="工单列表",Name ="工单待办",Description ="工单待办")]
        OrderAgent = 200117,
        #endregion

        #region 延期管理
        /// <summary>
        /// 延期管理
        /// </summary>
        [Display(GroupName = "业务管理", Name = "延期管理", Description = "延期管理")]
        DelayOrderManage = 200200,

        #region 延期待审批
        /// <summary>
        /// 延期待办
        /// </summary>
        [Display(GroupName = "延期待办", Name = "延期待办", Description = "延期待办")]
        DelayOrder = 200201,
        /// <summary>
        /// 延期审核
        /// </summary>
        [Display(GroupName = "延期待办", Name = "延期审核", Description = "延期审核")]
        DelayOrderAudit = 200202,
        #endregion

        #region 延期列表
        /// <summary>
        /// 延期列表
        /// </summary>
        [Display(GroupName = "业务管理",Name ="延期列表",Description ="延期列表")]
        DelaiedOrder = 200203,

        /// <summary>
        /// 延期审批
        /// </summary>
        [Display(GroupName = "业务管理", Name = "延期审批", Description = "延期审批")]
        DelaiedOrderAudit = 200204,
        /// <summary>
        /// 延期撤销
        /// </summary>
        [Display(GroupName = "业务管理", Name = "延期撤销", Description = "延期撤销")]
        DelaiedOrderRevoke = 200205,
        /// <summary>
        /// 延期退回
        /// </summary>
        [Display(GroupName = "业务管理", Name = "延期退回", Description = "延期退回")]
        DelaiedOrderReturn = 200206,
        #endregion
        #endregion

        #region 甄别管理
        /// <summary>
        /// 甄别管理
        /// </summary>
        [Display(GroupName ="业务管理",Name ="甄别管理",Description ="甄别管理")]
        OrderScreenManage = 200300,
        #region 甄别待办
        /// <summary>
        /// 甄别待办
        /// </summary>
        [Display(GroupName = "甄别待办", Name = "甄别待办", Description = "甄别待办")]
        ScreenOrder = 200301,
        /// <summary>
        /// 甄别审批
        /// </summary>
        [Display(GroupName = "甄别待办", Name = "甄别审批", Description = "甄别审批")]
        ScreenOrderAudit = 200302,
        /// <summary>
        /// 甄别退回
        /// </summary>
        [Display(GroupName = "甄别待办", Name = "甄别退回", Description = "甄别退回")]
        ScreenOrderReturn = 200303,
        #endregion

        #region 甄别待申请
        /// <summary>
        /// 待甄别列表
        /// </summary>
        [Display(GroupName = "业务管理", Name = "待甄别列表", Description = "待甄别列表")]
        CanOrderScreen = 200304,
        /// <summary>
        /// 申请甄别
        /// </summary>
        [Display(GroupName = "业务管理", Name = "申请甄别", Description = "申请甄别")]
        ApplyScreen = 200305,

        /// <summary>
        /// 修改甄别提起时限
        /// </summary>
        [Display(GroupName ="业务管理",Name ="修改甄别提起时限",Description = "修改甄别提起时限")]
        ModifyScreenTimeLimit = 200309,
        #endregion


        #region 甄别列表
        /// <summary>
        /// 甄别列表
        /// </summary>
        [Display(GroupName = "业务管理", Name = "甄别列表", Description = "甄别列表")]
        OrderScreen = 200306,
        /// <summary>
        /// 甄别审批
        /// </summary>
        [Display(GroupName = "业务管理", Name = "甄别审批", Description = "甄别审批")]
        OrderScreenAudit = 200307,
        /// <summary>
        /// 甄别退回
        /// </summary>
        [Display(GroupName = "业务管理", Name = "甄别退回", Description = "甄别退回")]
        OrderScreenReturn = 200308,
        #endregion



        #endregion

        #region 特提管理
        /// <summary>
        /// 特提管理
        /// </summary>
        [Display(GroupName ="特提管理",Name ="特提管理",Description ="特提管理")]
        SpecialOrderManage = 200400,

        #region 特提列表
        /// <summary>
        /// 特提列表
        /// </summary>
        [Display(GroupName = "特提列表", Name = "特提列表", Description = "特提列表")]
        SpecialOrder = 200401,
        /// <summary>
        /// 数据权限
        /// </summary>
        [Display(GroupName ="特提列表",Name ="数据权限",Description ="数据权限")]
        SpecialDataRole = 200406,
        #endregion

        #region 特提待审批
        /// <summary>
        /// 特提待审批
        /// </summary>
        [Display(GroupName = "特提待审批", Name = "特提待审批", Description = "特提待审批")]
        SpecialOrderApply = 200402,

        /// <summary>
        ///工单特提列表
        /// </summary>
        [Display(GroupName = "特提审核", Name = "工单特提列表", Description = "工单特提列表")]
        AuditSpecialOrderList = 200403,

        /// <summary>
        /// 特提审核
        /// </summary>
        [Display(GroupName = "特提审核", Name = "特提审核", Description = "特提审核")]
        AuditSpecial = 200404,
        /// <summary>
        /// 批量审批
        /// </summary>
        [Display(GroupName ="特提审核",Name ="批量审批",Description ="批量审批")]
        BatchAuditSpecial = 200405,

        #endregion

        #endregion

        #region 退回管理
        /// <summary>
        /// 退回管理
        /// </summary>
        [Display(GroupName ="退回管理",Description ="退回管理",Name ="退回管理")]
        BackOrderManage = 200500,

        #region 业务退回审批
        /// <summary>
        ///工单业务退回审批列表
        /// </summary>
        [Display(GroupName = "业务退回审批", Name = "工单业务退回审批列表", Description = "工单业务退回审批列表")]
        OrderPreviousList = 200501,

        /// <summary>
        /// 工单业务退回审批
        /// </summary>
        [Display(GroupName = "业务退回审批", Name = "业务退回审批", Description = "业务退回审批")]
        OrderPreviousAudit = 200502,
        /// <summary>
        /// 批量审批
        /// </summary>
        [Display(GroupName ="业务退回审批",Name ="批量审批",Description ="批量审批")]
        OrderPreviousBatchAudit = 200503,
        #endregion

        #region 省退回申请
        /// <summary>
        /// 省退回申请
        /// </summary>
        [Display(GroupName = "省退回申请", Name = "省退回申请", Description = "省退回申请")]
        SendBackOrder = 200503,

        /// <summary>
		/// 退回审核
		/// </summary>
		[Display(GroupName = "省退回申请", Name = "退回审核", Description = "退回审核")]
        AuditSendBack = 200504,
        #endregion

        #region 退回列表
        /// <summary>
        /// 退回列表
        /// </summary>
        [Display(GroupName ="退回列表",Name ="退回列表",Description ="退回列表")]
        OrderPreviousReadList = 200505,
        /// <summary>
        /// 数据范围
        /// </summary>
        [Display(GroupName ="退回列表",Name ="数据范围",Description ="数据范围")]
        OrderPreviousDataRange = 200506,
        #endregion

        #endregion

        #region 催办管理
        /// <summary>
        /// 催办管理
        /// </summary>
        [Display(GroupName ="催办管理",Name ="催办管理",Description ="催办管理")]
        UrgeOrderManage = 200600,

        #region 催办待办
        /// <summary>
        /// 催办待办
        /// </summary>
        [Display(GroupName = "催办待办", Name = "催办待办", Description = "催办待办")]
        OrderUrging = 200601,

        #endregion

        #region 催办查询
        /// <summary>
        /// 催办查询
        /// </summary>
        [Display(GroupName = "业务查询", Name = "催办查询", Description = "催办查询")]
        UrgeOrder = 200602,

        #endregion


        #endregion

        #region 督办管理
        /// <summary>
        /// 督办管理
        /// </summary>
        [Display(GroupName ="督办管理",Name ="督办管理",Description ="督办管理")]
        SuperviseOrderManage = 200700,

        #region 督办待办
        /// <summary>
        /// 督办待办
        /// </summary>
        [Display(GroupName = "督办管理", Name = "督办待办", Description = "督办待办")]
        OrderSupervise = 200701,
        /// <summary>
        /// 督办回复
        /// </summary>
        [Display(GroupName = "督办管理", Name ="督办回复",Description ="督办回复")]
        SuperviseOrderReply = 200702,
        #endregion

        #region 督办列表
        /// <summary>
        /// 督办列表
        /// </summary>
        [Display(GroupName = "督办管理", Name = "督办列表", Description = "督办列表")]
        SuperviseOrder = 200703,
        /// <summary>
        /// 回复督办
        /// </summary>
		[Display(GroupName = "督办管理", Name = "回复督办", Description = "回复督办")]
        ReplySuperviseOrder = 200704,
        #endregion
        #endregion

        #region 发布管理
        /// <summary>
        /// 发布管理
        /// </summary>
        [Display(GroupName ="发布管理",Name ="发布管理",Description ="发布管理")]
        PublishedOrderManage = 200800,

        #region 发布待办
        /// <summary>
        /// 发布待办
        /// </summary>
        [Display(GroupName = "发布待办", Name = "发布待办", Description = "发布待办")]
        PublishTodo = 200801,
        /// <summary>
        /// 发布工单
        /// </summary>
        [Display(GroupName = "发布待办", Name = "发布工单", Description = "发布工单")]
        PublishOrder = 200802,
        /// <summary>
        /// 批量发布工单
        /// </summary>
        [Display(GroupName ="发布待办",Name ="批量发布工单",Description ="批量发布工单")]
        BatchPublishOrder = 200803,
        /// <summary>
        /// 工单重办
        /// </summary>
        [Display(GroupName ="发布待办",Name ="工单重办",Description ="工单重办")]
        OrderRedo = 200806,
        /// <summary>
        /// 发布待办平级移动
        /// </summary>
        [Display(GroupName ="发布待办",Name ="平级移动",Description ="平级移动")]
        PublishMigration = 200807,
        /// <summary>
        /// 数据范围
        /// </summary>
        [Display(GroupName ="发布待办",Name ="数据范围",Description ="数据范围")]
        PublishDataRange = 200808,
        /// <summary>
        /// 工单退回
        /// </summary>
        [Display(GroupName ="发布待办",Name ="工单退回",Description ="工单退回")]
        PublishOrderReturn = 200809,
        #endregion

        #region 发布列表
        /// <summary>
        /// 发布列表
        /// </summary>
        [Display(GroupName = "业务管理", Name = "发布列表", Description = "发布列表")]
        PublishedOrder = 200804,

        /// <summary>
        /// 修改发布
        /// </summary>
        [Display(GroupName = "业务管理", Name = "修改发布", Description = "修改发布")]
        PublishedModify = 200805,
        #endregion

        #endregion

        #region 回访管理
        /// <summary>
        /// 回访管理
        /// </summary>
        [Display(GroupName ="回访管理",Name ="回访管理",Description ="回访管理")]
        VisitOrderManage = 200900,

        #region 回访待办
        /// <summary>
        /// 回访待办
        /// </summary>
        [Display(GroupName = "回访待办", Name = "回访待办", Description = "回访待办")]
        VisitTodo = 200901,

        /// <summary>
        /// 回访
        /// </summary>
        [Display(GroupName = "回访待办", Name = "回访", Description = "回访")]
        Visit = 200902,

        /// <summary>
        /// 分配回访人
        /// </summary>
        [Display(GroupName = "回访待办", Name = "分配回访人", Description = "分配回访人")]
        MultiplePeople = 200903,
        /// <summary>
        /// 平级移动
        /// </summary>
        [Display(GroupName ="回访待办", Name ="平级移动",Description ="平级移动")]
        OrderVisitMigration = 200913,
        /// <summary>
        /// 数据范围
        /// </summary>
        [Display(GroupName ="回访待办",Name ="数据范围",Description ="数据范围")]
        OrderVisitDataRange = 200914,
        /// <summary>
        /// 工单类型
        /// </summary>
        [Display(GroupName ="回访待办",Name ="工单类型",Description ="工单类型")]
        OrderTypeForVisit = 200915,
        /// <summary>
        /// 短信回访
        /// </summary>
        [Display(GroupName = "回访待办", Name ="短信回访",Description ="短信回访")]
        SmsOrderVisit = 200916,
        /// <summary>
        /// 批量回访
        /// </summary>
        [Display(GroupName ="回访待办",Name ="批量回访",Description ="批量回访")]
        BatchOrderVisit = 200917,
        /// <summary>
        /// 重办
        /// </summary>
        [Display(GroupName ="回访待办",Name ="重办",Description ="重办")]
        OrderVisitRedo = 200919,
        #endregion

        #region 回访列表
        /// <summary>
        /// 回访列表
        /// </summary>
        [Display(GroupName = "业务管理", Name = "回访列表", Description = "回访列表")]
        OrderVisited = 200904,
        /// <summary>
        /// 修改回访结果
        /// </summary>
        [Display(GroupName ="业务管理",Name ="修改回访结果",Description ="修改回访结果")]
        ModifyOrderVisit = 200918,
        #endregion

        #region 智能回访任务
        /// <summary>
        /// 智能回访任务
        /// </summary>
        [Display(GroupName = "智能回访", Name = "智能回访任务", Description = "智能回访任务")]
        AiVisitTask = 200905,
        /// <summary>
        /// 新增智能回访任务
        /// </summary>
        [Display(GroupName = "智能回访", Name = "新增智能回访任务", Description = "新增智能回访任务")]
        AddAiVisitTask = 200906,
        /// <summary>
        /// 终止回访任务
        /// </summary>
        [Display(GroupName ="智能回访",Name ="终止回访任务",Description ="终止回访任务")]
        CloseAiVisit = 200910,
        /// <summary>
        /// 启动任务
        /// </summary>
        [Display(GroupName ="智能回访",Name ="启动任务",Description ="启动任务")]
        AiVisitStartTask = 200911,
        /// <summary>
        /// 暂停任务
        /// </summary>
        [Display(GroupName ="智能回访",Name ="暂停任务",Description ="暂停任务")]
        AiVisitPauseTask = 200912,

        #endregion

        #region 扭转待评判
        /// <summary>
        /// 扭转评判
        /// </summary>
        [Display(GroupName ="扭转评价",Name ="扭转待评判",Description ="扭转待评判")]
        VisitReverseList = 200907,

        /// <summary>
        /// 批量扭转评判
        /// </summary>
        [Display(GroupName = "扭转评价", Name ="批量扭转评判",Description ="批量扭转评判")]
        BatchVisitReverse = 200908,
        /// <summary>
        /// 扭转评判
        /// </summary>
        [Display(GroupName = "扭转评价", Name ="扭转评判",Description ="扭转评判")]
        VisitReverse = 200909,
        #endregion

        #endregion

        #region 超期管理
        /// <summary>
        /// 超期管理
        /// </summary>
        [Display(GroupName ="业务管理",Name ="超期管理",Description ="超期管理")]
        OverdueSoonOrderManage = 201000,


        #region 工单即将超期
        /// <summary>
        /// 工单即将超期
        /// </summary>
        [Display(GroupName = "工单即将超期", Name = "工单即将超期", Description = "工单即将超期")]
        OverdueSoonOrder = 201001,

        #endregion

        #region 工单超期列表
        /// <summary>
        /// 工单超期列表
        /// </summary>
        [Display(GroupName = "工单超期列表", Name = "工单超期列表", Description = "工单超期列表")]
        OverdueOrder = 201002,

        #endregion

        #endregion

        #region 会签查询
        /// <summary>
        /// 会签查询
        /// </summary>
        [Display(GroupName = "会签查询", Name = "会签查询", Description = "会签查询")]
        CounterSign = 201100,

        #endregion

        #region 观察件查询
        /// <summary>
        /// 观察件查询
        /// </summary>
        [Display(GroupName = "业务查询", Name = "观察件查询")]
        OrderObserve = 201200,

        #endregion

        #region 终结件查询
        /// <summary>
        /// 工单终结列表
        /// </summary>
        [Display(GroupName = "业务查询", Name = "工单终结查询", Description = "工单终结查询")]
        OrderFinality = 201300,

        #endregion

        #region 重复性事件管理
        /// <summary>
        /// 重复性事件管理
        /// </summary>
        [Display(GroupName = "重复性事件管理", Name = "重复性事件管理", Description = "重复性事件管理")]
        RepeatableEvent = 201400,

        /// <summary>
		/// 重复性事件列表
		/// </summary>
		[Display(GroupName = "RepeatableEvent", Name = "重复性事件列表", Description = "重复性事件列表")]
        RepeatableEventList = 201401,

        /// <summary>
        /// 修改重复性事件
        /// </summary>
        [Display(GroupName = "RepeatableEvent", Name = "修改重复性事件", Description = "修改重复性事件")]
        UpdateRepeatableEvent = 201402,


        #endregion

        #region 二次回访申请
        [Display(GroupName = "二次回访申请",Name ="二次回访申请")]
        OrderVisitAgain = 201000,

        /// <summary>
        /// 可申请二次回访列表
        /// </summary>
        [Display(GroupName = "二次回访申请", Name = "可申请二次回访列表", Description = "可申请二次回访列表")]
        OrderVisitAgainList = 201001,

        /// <summary>
        /// 申请二次回访
        /// </summary>
        [Display(GroupName = "二次回访申请", Name = "申请二次回访", Description = "申请二次回访")]
        ApplyOrderVisit = 201002,
        #endregion

        #region 二次回访审核
        /// <summary>
        /// 二次回访审核
        /// </summary>
        [Display(GroupName = "二次回访审核",Name = "二次回访审核",Description ="二次回访审核")]
        VisitApply  = 201100,

        /// <summary>
        /// 二次回访申请列表
        /// </summary>
        [Display(GroupName = "二次回访审核", Name = "二次回访申请列表", Description = "二次回访申请列表")]
        VisitApplyList = 201101,

        /// <summary>
        /// 审核二次回访
        /// </summary>
        [Display(GroupName = "ExaminOrderVisit", Name = "二次回访审核", Description = "二次回访审核")]
        ExaminOrderVisit = 201102,
        #endregion

        #region 二次办理
        /// <summary>
        /// 二次办理
        /// </summary>
        [Display(GroupName ="二次办理",Name ="二次办理",Description ="二次办理")]
        SecondHandle = 201500,

        #region 二次办理申请
        /// <summary>
        /// 二次办理申请
        /// </summary>
        [Display(GroupName = "二次办理申请",Name ="二次办理申请",Description ="二次办理申请")]
        SecondHandleApply = 201501,

        /// <summary>
        /// 申请二次办理
        /// </summary>
        [Display(GroupName ="申请二次办理",Name ="申请二次办理",Description ="申请二次办理")]
        ApplySecondHandle = 201502,
        #endregion

        #region 二次办理审批
        /// <summary>
        /// 二次办理审批
        /// </summary>
        [Display(GroupName ="二次办理审批",Name ="二次办理审批",Description ="二次办理审批")]
        SecondHandleApproval = 201503,

        /// <summary>
        /// 二次办理退回
        /// </summary>
        [Display(GroupName ="二次办理退回",Name ="二次办理退回",Description ="二次办理退回")]
        SecondHandleReturn = 201504,
        /// <summary>
        /// 二次办理审批
        /// </summary>
        [Display(GroupName ="二次办理审批",Name ="二次办理审批",Description ="二次办理审批")]
        ApprovalSecondHandle  = 201505,
        /// <summary>
        /// 批量审批
        /// </summary>
        [Display(GroupName ="二次办理审批",Name ="批量审批",Description ="批量审批")]
        BatchApprovalSecondHandle = 201506,

        #endregion

        #region 二次办理查询
        /// <summary>
        /// 二次办理查询
        /// </summary>
        [Display(GroupName = "二次办理", Name = "二次办理查询", Description = "二次办理查询")]
        SecondHandleQuery = 201507,

        #endregion
        #endregion

        #region 工单修改
        /// <summary>
        /// 工单修改列表
        /// </summary>
        [Display(GroupName ="工单修改列表",Name = "工单修改列表", Description = "工单修改列表")]
        ModifyOrderList = 201600,
        /// <summary>
        /// 交办单导出
        /// </summary>
        [Display(GroupName ="工单修改",Name ="交办单导出",Description ="交办单导出")]
        ModifyOrderOrderJbdExport = 201601,

        /// <summary>
        /// 工单修改
        /// </summary>
        [Display(GroupName ="工单修改",Name ="工单修改",Description ="工单修改")]
        ModifyOrder = 201602,
        #endregion
        #endregion

        #region 质检管理（40,00,00）
        /// <summary>
        /// 质检管理
        /// </summary>
        [Display(GroupName = "质检管理",Name ="质检管理",Description ="质检管理")]
        QualityManage = 400000,

        #region 质检中心
        /// <summary>
        /// 质检中心
        /// </summary>
        [Display(GroupName = "质检管理",Name = "质检中心",Description = "质检中心")]
        QualityCenter = 400100,

        /// <summary>
        /// 工单详情
        /// </summary>
        [Display(GroupName = "质检中心",Name ="工单详情",Description = "工单详情")]
        OrderInfo = 400101,
        /// <summary>
        /// 质检
        /// </summary>
        [Display(GroupName = "质检",Name = "质检",Description ="质检")]
        QualityOrder = 400102,

        #endregion

        #region 已质检列表
        /// <summary>
        /// 已质检列表
        /// </summary>
        [Display(GroupName = "已质检列表",Name = "已质检列表",Description ="已质检列表")]
        QualitiedList = 400200,
        /// <summary>
        /// 质检查看
        /// </summary>
        [Display(GroupName = "已质检列表",Name ="质检查看",Description = "质检查看")]
        QualitieyInfo = 400201,
        /// <summary>
        /// 修改质检
        /// </summary>
        [Display(GroupName = "已质检列表", Name = "修改质检", Description = "修改质检")]
        UpdateQuality = 400104,
        #endregion

        #region 质检项目管理
        /// <summary>
        /// 质检项目管理
        /// </summary>
        [Display(GroupName = "质检项目管理",Name ="质检项目管理",Description = "质检项目管理")]
        QualityItem = 400300,
        /// <summary>
        /// 质检项目列表
        /// </summary>
        [Display(GroupName = "质检项目管理", Name = "质检项目列表", Description = "质检项目列表")]
        QualityItemList = 400301,

        /// <summary>
        /// 新增质检项目
        /// </summary>
        [Display(GroupName = "QualityItem", Name = "新增质检项目", Description = "新增质检项目")]
        AddQualityItem = 400302,

        /// <summary>
        /// 删除质检项目
        /// </summary>
        [Display(GroupName = "QualityItem", Name = "删除质检项目", Description = "删除质检项目")]
        DeleteQualityItem = 400303,

        /// <summary>
		/// 修改质检项目
		/// </summary>
		[Display(GroupName = "QualityItem", Name = "修改质检项目", Description = "修改质检项目")]
        UpdateQualityItem = 400304,
        #endregion

        #region 质检模版管理
        /// <summary>
        /// 质检模板管理
        /// </summary>
        [Display(GroupName = "质检模板管理",Name ="质检模板管理",Description ="质检模板管理")]
        QualityTemplate = 400400,
        /// <summary>
        /// 质检模版列表
        /// </summary>
        [Display(GroupName = "QualityTemplate", Name = "质检模版列表", Description = "质检模版列表")]
        QualityTemplateList = 400401,

        /// <summary>
        /// 新增质检模版
        /// </summary>
        [Display(GroupName = "QualityTemplate", Name = "新增质检模版", Description = "新增质检模版")]
        AddQualityTemplate = 400402,

        /// <summary>
        /// 删除质检模版
        /// </summary>
        [Display(GroupName = "QualityTemplate", Name = "删除质检模版", Description = "删除质检模版")]
        DeleteQualityTemplate = 400403,

        /// <summary>
        /// 修改质检模版
        /// </summary>
        [Display(GroupName = "QualityTemplate", Name = "修改质检模版", Description = "修改质检模版")]
        UpdateQualityTemplate = 400404,

        /// <summary>
        /// 启禁用质检模版
        /// </summary>
        [Display(GroupName = "QualityTemplate", Name = "启禁用质检模版", Description = "启禁用质检模版")]
        EnableQualityTemplate = 400405,
        #endregion

        #region 质检违禁词管理
        /// <summary>
        /// 质检违禁词管理
        /// </summary>
        [Display(GroupName = "质检违禁词管理",Name = "质检违禁词管理",Description ="质检违禁词管理")]
        QualityProhibited = 400500,

        /// <summary>
        /// 质检违禁词列表
        /// </summary>
        [Display(GroupName = "QualityProhibited", Name = "质检违禁词列表", Description = "质检违禁词列表")]
        QualityProhibitedList = 400501,

        /// <summary>
        /// 新增质检违禁词
        /// </summary>
        [Display(GroupName = "QualityProhibited", Name = "新增质检违禁词", Description = "新增质检违禁词")]
        AddQualityProhibited = 400502,

        /// <summary>
        /// 删除质检违禁词
        /// </summary>
        [Display(GroupName = "QualityProhibited", Name = "删除质检违禁词", Description = "删除质检违禁词")]
        DeleteQualityProhibited = 400503,

        /// <summary>
        /// 修改质检违禁词
        /// </summary>
        [Display(GroupName = "QualityProhibited", Name = "修改质检违禁词", Description = "修改质检违禁词")]
        UpdateQualityProhibited = 400504,

        #endregion

        #endregion

        #region 系统管理（50,00,00）

        /// <summary>
        /// 系统管理
        /// </summary>
        [Display(GroupName = "系统管理", Name = "系统管理", Description = "系统管理")]
        SystemManage = 500000,

        #region 组织架构
        /// <summary>
        /// 组织架构
        /// </summary>
        [Display(GroupName = "系统管理", Name = "组织架构", Description = "组织架构")]
        OrgManage = 500100,

        /// <summary>
        /// 组织架构树形列表
        /// </summary>
        [Display(GroupName = "系统设置", Name = "组织架构树形列表", Description = "组织架构树形列表")]
        GetOrgJson = 500101,
        /// <summary>
        /// 新增组织
        /// </summary>
        [Display(GroupName = "系统设置", Name = "新增组织", Description = "新增组织")]
        AddOrg = 500102,
        /// <summary>
        /// 修改组织
        /// </summary>
        [Display(GroupName = "系统设置", Name = "修改组织", Description = "修改组织")]
        UpdateOrg = 500103,

        #endregion

        #region 用户管理
        /// <summary>
        /// 用户管理
        /// </summary>
        [Display(GroupName = "系统管理",Name = "用户管理",Description ="用户管理")]
        UserManage = 500200,

        /// <summary>
        /// 分页查询用户
        /// </summary>
        [Display(GroupName = "用户管理", Name = "分页查询用户", Description = "分页查询用户")]
        QueryPagedUser = 500201,
        /// <summary>
        /// 新增用户
        /// </summary>
        [Display(GroupName = "用户管理", Name = "新增用户", Description = "新增用户")]
        AddUser = 500202,
        /// <summary>
        /// 更新用户
        /// </summary>
        [Display(GroupName = "用户管理", Name = "更新用户", Description = "更新用户")]
        UpdateUser = 500203,
        /// <summary>
        /// 删除用户
        /// </summary>
        [Display(GroupName = "用户管理", Name = "删除用户", Description = "删除用户")]
        RemoveUser = 500204,
        /// <summary>
        /// 重置密码
        /// </summary>
        [Display(GroupName ="用户管理",Name ="重置密码",Description ="重置密码")]
        ResetPwd = 500205,
        #endregion

        #region 角色管理
        /// <summary>
        /// 角色管理
        /// </summary>
        [Display(GroupName = "系统管理",Name = "角色管理",Description ="角色管理")]
        RoleManage = 500300,
        /// <summary>
        /// 分页查询角色
        /// </summary>
        [Display(GroupName = "角色管理", Name = "分页查询角色", Description = "分页查询角色")]
        QueryPagedRole = 500301,
        /// <summary>
        /// 新增角色
        /// </summary>
        [Display(GroupName = "角色管理", Name = "新增角色", Description = "新增角色")]
        AddRole = 500302,
        /// <summary>
        /// 删除角色
        /// </summary>
        [Display(GroupName = "角色管理", Name = "删除角色", Description = "删除角色")]
        RemoveRole = 500303,
        /// <summary>
        /// 更新角色
        /// </summary>
        [Display(GroupName = "角色管理", Name = "更新角色", Description = "更新角色")]
        UpdateRole = 500304,
        #region 应用权限管理
        /// <summary>
        /// 分配权限
        /// </summary>
        [Display(GroupName = "角色管理", Name = "分配权限", Description = "分配权限")]
        AllocationAuthority = 500305,
        
        #endregion
        #region 数据权限管理
        /// <summary>
        /// 数据权限
        /// </summary>
        [Display(GroupName = "角色管理", Name = "数据权限", Description = "数据权限")]
        DataAuthorityByRole = 500306,
        
        #endregion
        #endregion

        #region 菜单管理（500400）
        /// <summary>
        /// 菜单管理
        /// </summary>
        [Display(GroupName = "系统设置", Name = "菜单管理", Description = "菜单管理")]
        GetMenuJson = 500400,
        /// <summary>
        /// 新增菜单
        /// </summary>
        [Display(GroupName = "系统设置", Name = "新增菜单", Description = "新增菜单")]
        AddMenu = 500401,
        /// <summary>
        /// 修改菜单
        /// </summary>
        [Display(GroupName = "系统设置", Name = "修改菜单", Description = "修改菜单")]
        UpdateMenu = 500402,
        /// <summary>
        /// 删除菜单
        /// </summary>
        [Display(GroupName = "系统设置", Name = "删除菜单", Description = "删除菜单")]
        RemoveMenu = 500403,
        #endregion

        #region 配置管理
        /// <summary>
        /// 配置管理
        /// </summary>
        [Display(GroupName = "系统设置",Name ="配置管理",Description = "配置管理")]
        ConfigManage = 500500,

        #region 字典管理
        /// <summary>
        /// 字典管理
        /// </summary>
        [Display(GroupName = "配置管理",Name ="字典管理",Description ="字典管理")]
        SysDicManage = 500600,
        /// <summary>
        /// 字典类型列表
        /// </summary>
        [Display(GroupName = "系统设置", Name = "字典类型列表", Description = "字典类型列表")]
        GetSysDicType = 500601,
        /// <summary>
        /// 字典数据列表
        /// </summary>
        [Display(GroupName = "系统设置", Name = "字典数据列表", Description = "字典数据列表")]
        GetSysDicData = 500602,
        /// <summary>
        /// 获取字典对象
        /// </summary>
        [Display(GroupName = "系统设置", Name = "获取字典对象", Description = "获取字典对象")]
        SysDicDataModel = 500603,
        /// <summary>
        /// 新增字典数据
        /// </summary>
        [Display(GroupName = "系统设置", Name = "新增字典数据", Description = "新增字典数据")]
        AddDicData = 500604,
        /// <summary>
        /// 修改字典数据
        /// </summary>
        [Display(GroupName = "系统设置", Name = "修改字典数据", Description = "修改字典数据")]
        UpdateDicData = 500605,

        #endregion

        #region 流程配置
        /// <summary>
        /// 流程配置
        /// </summary>
        [Display(GroupName = "系统设置",Name ="流程配置",Description = "流程配置")]
        FlowManage = 500700,

        /// <summary>
        /// 查询流程模板
        /// </summary>
        [Display(GroupName = "系统设置", Name = "查询流程模板", Description = "查询流程模板")]
        FlowDefinitionQuery = 500701,

        /// <summary>
        /// 新建流程模板
        /// </summary>
        [Display(GroupName = "系统设置", Name = "新建流程模板", Description = "新建流程模板")]
        FlowDefinitionAdd = 500702,

        /// <summary>
        /// 删除流程模板
        /// </summary>
        [Display(GroupName = "系统设置", Name = "删除流程模板", Description = "删除流程模板")]
        FlowDefinitionRemove = 500703,

        /// <summary>
        /// 更新流程模板
        /// </summary>
        [Display(GroupName = "系统设置", Name = "更新流程模板", Description = "更新流程模板")]
        FlowDefinitionUpdate = 500704,

        /// <summary>
        /// 发布流程模板
        /// </summary>
        [Display(GroupName = "系统设置", Name = "发布流程模板", Description = "发布流程模板")]
        FlowDefinitionPublish = 500705,
        /// <summary>
        /// 流程编辑页面
        /// </summary>
        [Display(GroupName = "系统设置",Name ="流程编辑页面",Description ="流程编辑页面")]
        FlowEditPage = 500706,
        /// <summary>
        /// 配置模板
        /// </summary>
        [Display(GroupName ="系统设置",Name = "配置模板",Description = "配置模板")]
        SetDefinition = 500707,
        /// <summary>
        /// 清除配置
        /// </summary>
        [Display(GroupName ="系统设置",Name ="清除配置",Description ="清除配置")]
        ClearSet = 500708,
        #endregion

        #region 节假日设置
        /// <summary>
        /// 工作时间配置
        /// </summary>
        [Display(GroupName = "系统设置",Name ="工作时间配置",Description ="工作时间配置")]
        DaySettings = 501000,

        /// <summary>
        /// 节假日设置列表
        /// </summary>
        [Display(GroupName = "系统设置", Name = "节假日设置", Description = "节假日设置")]
        DaySetingsList = 501001,
        /// <summary>
        /// 设置节假日
        /// </summary>
        [Display(GroupName = "系统设置", Name = "设置节假日", Description = "设置节假日")]
        SetDaySetting = 501002,
        #endregion

        #endregion

        #region 系统参数
        /// <summary>
        /// 系统参数
        /// </summary>
        [Display(GroupName ="系统设置",Name ="系统参数",Description ="系统参数")]
        SysSettings = 500800,
        /// <summary>
        /// 获取系统参数列表
        /// </summary>
        [Display(GroupName = "系统设置", Name = "获取系统参数列表", Description = "获取系统参数列表")]
        GetSysSettings = 500801,
        /// <summary>
        /// 更新设置
        /// </summary>
        [Display(GroupName = "系统设置", Name = "更新设置", Description = "更新设置")]
        ModifySettings = 500802,

        /// <summary>
        /// 获取系统参数对象
        /// </summary>
        [Display(GroupName = "系统设置", Name = "获取系统参数对象", Description = "获取系统参数对象")]
        GetSettingEntity = 500803,

        /// <summary>
        /// 新增系统参数
        /// </summary>
        [Display(GroupName = "系统设置", Name = "新增系统参数", Description = "新增系统参数")]
        AddSetting = 500804,


        #endregion

        #region 系统日志
        /// <summary>
        /// 系统日志
        /// </summary>
        [Display(GroupName = "系统管理",Name ="系统日志",Description = "系统日志")]
        SystemLog = 500900,
        /// <summary>
        /// 日志明细
        /// </summary>
        [Display(GroupName ="系统管理",Name ="日志明细",Description ="日志明细")]
        SystemLogDetail = 500901,

        #endregion

        #region 排班管理（501100）
        /// <summary>
        /// 排班管理
        /// </summary>
        [Display(GroupName ="系统管理",Name ="排班管理",Description ="排班管理")]
        SchedulingManage = 501100,

        #region 排班人员管理
        /// <summary>
        /// 排班人员管理
        /// </summary>
        [Display(GroupName ="排班管理",Name ="排班人员管理",Description ="排班人员管理")]
        SchedulingUserManage = 501101,

        /// <summary>
        /// 选择用户
        /// </summary>
        [Display(GroupName ="排班人员管理",Name ="选择用户",Description ="选择用户")]
        SchedulingChoiceUser = 501102,
        /// <summary>
        /// 删除人员
        /// </summary>
        [Display(GroupName ="排班人员管理",Name ="删除人员",Description = "删除人员")]
        SchedulingDelUser = 501103,
        /// <summary>
        /// 批量删除人员
        /// </summary>
        [Display(GroupName ="排班人员管理",Name ="批量删除人员",Description ="批量删除人员")]
        SchedulingBatchDelUser = 501104,
        #endregion

        #region 班次管理
        /// <summary>
        /// 班次管理
        /// </summary>
        [Display(GroupName ="排班管理",Name ="班次管理",Description ="班次管理")]
        ShiftManage = 501105,
        /// <summary>
        /// 新增班次
        /// </summary>
        [Display(GroupName ="班次管理",Name ="新增班次",Description ="新增班次")]
        AddShift = 501106,
        /// <summary>
        /// 编辑班次
        /// </summary>
        [Display(GroupName ="班次管理",Name ="编辑班次",Description ="编辑班次")]
        EditShift = 501107,
        /// <summary>
        /// 删除班次
        /// </summary>
        [Display(GroupName ="班次管理",Name ="删除班次",Description ="删除班次")]
        DelShift = 501108,
        /// <summary>
        /// 批量删除班次
        /// </summary>
        [Display(GroupName ="班次管理",Name ="批量删除班次",Description ="批量删除班次")]
        DelBatchShift = 501109,
        #endregion

        #region 排班管理
        /// <summary>
        /// 排班管理
        /// </summary>
        [Display(GroupName ="排班管理",Name ="排班管理",Description ="排班管理")]
        SchedulingDataManage = 501110,
        /// <summary>
        /// 批量排班
        /// </summary>
        [Display(GroupName ="排班管理",Name ="批量排班",Description ="批量排班")]
        BatchScheduling = 501111,

        #endregion

        #endregion


        #endregion

        #region 知识库（60,00,00）
        /// <summary>
        /// 知识库
        /// </summary>
        [Display(GroupName = "知识库", Name = "知识库", Description = "知识库")]
        KnowledgeBase = 600000,

        #region 知识库新增/编辑
        /// <summary>
        /// 知识库新增、编辑
        /// </summary>
        [Display(GroupName = "知识库",Name = "知识库新增、编辑",Description = "知识库新增、编辑")]
        KnowledgeAddOrEditBase = 600100,

        #endregion

        #region 知识库查看
        /// <summary>
        /// 知识库
        /// </summary>
        [Display(GroupName="知识库",Name ="知识库查看",Description ="知识库")]
        KnowledgePreview = 600200,
        #endregion

        #region 知识库管理
        /// <summary>
        /// 知识库管理
        /// </summary>
        [Display(GroupName = "知识库", Name = "知识库管理", Description = "知识库管理")]
        KnowledgeManage = 600300,

        #region 知识库
        /// <summary>
        /// 新增审核按钮
        /// </summary>
        [Display(GroupName = "知识库", Name = "新增审核按钮", Description = "提交审核按钮")]
        AddKnowledge = 600302,
        /// <summary>
        /// 知识库查看
        /// </summary>
        [Display(GroupName ="知识库",Name = "知识库查看",Description ="知识库查看")]
        KnowledgeRead = 600303,

        /// <summary>
        /// 知识修改
        /// </summary>
        [Display(GroupName = "知识库", Name = "知识修改", Description = "知识修改")]
        KnowledgeUpdate = 600304,
        /// <summary>
        /// 知识删除
        /// </summary>
        [Display(GroupName = "知识库管理", Name = "知识删除", Description = "知识删除")]
        KnowledgeDelete = 600305,
        /// <summary>
        /// 知识下架
        /// </summary>
        [Display(GroupName = "知识库管理", Name = "知识下架", Description = "知识下架")]
        KnowledgeOffShelf = 600306,
        /// <summary>
        /// 知识上架
        /// </summary>
        [Display(GroupName = "知识库管理", Name = "知识上架", Description = "知识上架")]
        KnowledgeOnTheShelf = 600307,

        #endregion

        #endregion

        #region 知识检索
        /// <summary>
        /// 知识检索
        /// </summary>
        [Display(GroupName = "知识库", Name = "知识检索", Description = "知识检索")]
        KnowledgeRetrieval = 600400,
        /// <summary>
        /// 知识库检索列表
        /// </summary>
        [Display(GroupName = "知识库",Name ="知识库检索列表",Description ="知识库检索列表")]
        KnowledgeRetrievalList = 600401,
        #endregion

        #region 知识纠错
        /// <summary>
        /// 知识库纠错
        /// </summary>
        [Display(GroupName = "知识库",Name ="知识库纠错",Description = "知识库纠错")]
        KnowledgeCorrection = 600500,

        /// <summary>
        /// 知识纠错列表
        /// </summary>
        [Display(GroupName = "KnowledgeCorrection", Name = "知识纠错列表", Description = "知识纠错列表")]
        KnowledgeCorrectionList = 600501,

        /// <summary>
        /// 知识纠错实体
        /// </summary>
        [Display(GroupName = "KnowledgeCorrection", Name = "知识纠错实体", Description = "知识纠错实体")]
        KnowledgeCorrectionEntity = 600502,

        /// <summary>
        /// 答复知识纠错
        /// </summary>
        [Display(GroupName = "KnowledgeCorrection", Name = "答复知识纠错", Description = "答复知识纠错")]
        ReplyKnowledgeCorrection = 600503,
        #endregion

        #region 知识提问
        /// <summary>
        /// 知识库提问
        /// </summary>
        [Display(GroupName = "知识库",Name ="知识库提问",Description = "知识库提问")]
        KnowledgeQuestions = 600600,

        /// <summary>
        /// 知识提问列表
        /// </summary>
        [Display(GroupName = "知识库", Name = "知识提问列表", Description = "知识提问列表")]
        KnowledgeQuestionsList = 600601,

        /// <summary>
        /// 知识提问实体
        /// </summary>
        [Display(GroupName = "知识库", Name = "知识提问实体", Description = "知识提问实体")]
        KnowledgeQuestionsEntity = 600602,

        /// <summary>
        /// 答复知识提问
        /// </summary>
        [Display(GroupName = "知识库", Name = "答复知识提问", Description = "答复知识提问")]
        ReplyKnowledgeQuestions = 600603,
        #endregion

        #region 知识收藏
        /// <summary>
        /// 知识库收藏
        /// </summary>
        [Display(GroupName = "知识库",Name ="知识库收藏",Description = "知识库收藏")]
        KnowledgeCollect = 600700,

        /// <summary>
        /// 知识收藏列表
        /// </summary>
        [Display(GroupName = "知识库", Name = "知识收藏列表", Description = "知识收藏列表")]
        KnowledgeCollectList = 600701,

        /// <summary>
        /// 知识收藏
        /// </summary>
        [Display(GroupName = "知识库", Name = "知识收藏", Description = "知识收藏")]
        AddKnowledgeCollect = 600702,

        /// <summary>
        /// 知识评分
        /// </summary>
        [Display(GroupName = "知识库", Name = "知识评分", Description = "知识评分")]
        AddKnowledgeScore = 600703,
        #endregion

        #region 知识库基础设置
        /// <summary>
        /// 知识库基础设置
        /// </summary>
        [Display(GroupName = "知识库", Name = "知识库基础设置", Description = "知识库基础设置")]
        KnowledgeBasicSettings = 600800,

        #region 知识规范
        /// <summary>
        /// 知识规范
        /// </summary>
        [Display(GroupName = "知识库", Name = "知识规范", Description = "知识规范")]
        KnowledgeStandard = 600801,
        /// <summary>
        /// 查询知识规范
        /// </summary>
        [Display(GroupName = "知识库", Name = "查询知识规范", Description = "查询知识规范")]
        KnowledgeStandardInfo = 600802,
        /// <summary>
        /// 修改知识规范
        /// </summary>
        [Display(GroupName = "知识库", Name = "修改知识规范", Description = "修改知识规范")]
        KnowledgeStandardUpdate = 600803,

        #endregion

        #region 类型管理
        /// <summary>
        /// 知识类型管理
        /// </summary>
        [Display(GroupName = "知识库",Name ="知识类型管理",Description = "知识类型管理")]
        KnowledgeTypeMange = 600900,
        /// <summary>
        /// 类型管理列表
        /// </summary>
        [Display(GroupName = "知识库", Name = "类型管理列表", Description = "类型管理列表")]
        KnowledgeTypeMangeList = 600901,
        /// <summary>
        /// 添加分类
        /// </summary>
        [Display(GroupName = "知识库", Name = "添加分类", Description = "添加分类")]
        AddKnowledgeType = 600902,
        /// <summary>
        /// 修改分类
        /// </summary>
        [Display(GroupName = "知识库", Name = "修改分类", Description = "修改分类")]
        UpdateKnowledgeType = 600903,
        /// <summary>
        /// 删除分类
        /// </summary>
        [Display(GroupName = "类型管理", Name = "删除分类", Description = "删除分类")]
        RemoveKnowledgeType = 600904,
        /// <summary>
        /// 关联组织
        /// </summary>
        [Display(GroupName ="类型管理",Name ="关联组织",Description ="关联组织")]
        CorrelationOrg = 600905,
        #endregion

        #endregion

        #endregion

        #region 辅助功能（70,00,00）

        /// <summary>
        /// 辅助功能
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "辅助功能", Description = "辅助功能")]
        Auxiliary = 700000,

        #region 公告
        /// <summary>
        /// 公告
        /// </summary>
        [Display(GroupName = "辅助功能",Name = "公告",Description = "公告")]
        Bulletin = 700100,
        /// <summary>
        /// 新增公告
        /// </summary>
        [Display(GroupName = "AddBulletin", Name = "新增公告", Description = "新增公告")]
        AddBulletin = 700103,
        /// <summary>
        /// 审核公告
        /// </summary>
        [Display(GroupName = "ExamineBulletin", Name = "审核公告", Description = "审核公告")]
        ExamineBulletin = 700104,

        /// <summary>
        /// 提交公告
        /// </summary>
        [Display(GroupName = "CommitBulletin", Name = "提交公告", Description = "提交公告")]
        CommitBulletin = 700105,
        /// <summary>
        /// 修改公告
        /// </summary>
        [Display(GroupName = "UpdateBulletin", Name = "修改公告", Description = "修改公告")]
        UpdateBulletin = 700106,
        /// <summary>
        /// 删除公告
        /// </summary>
        [Display(GroupName = "DelBulletin", Name = "删除公告", Description = "删除公告")]
        DelBulletin = 700107,
        /// <summary>
        /// 公告上架
        /// </summary>
        [Display(GroupName ="UpBulletin",Name = "公告上架",Description ="公告上架")]
        UpBulletin = 700108,
        /// <summary>
        /// 公告下架
        /// </summary>
        [Display(GroupName ="DownBulletin",Name ="公告下架",Description ="公告下架")]
        DownBulletin = 700109,
        #endregion

        #region 通知

        /// <summary>
        /// 通知
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "通知", Description = "通知")]
        Circular = 700200,

        /// <summary>
        /// 查询通知列表
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "查询通知列表", Description = "查询通知列表")]
        QueryCircularList = 700201,
        /// <summary>
        /// 新增通知
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "新增通知", Description = "新增通知")]
        AddCircular = 700203,

        /// <summary>
        /// 审核通知
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "审核通知", Description = "审核通知")]
        ExamineCircular = 700204,

        /// <summary>
        /// 提交通知
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "提交通知", Description = "提交通知")]
        CommitCircular = 700205,

        /// <summary>
        /// 修改通知
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "修改通知", Description = "修改通知")]
        UpdateCircular = 700206,

        /// <summary>
        /// 删除通知
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "删除通知", Description = "删除通知")]
        DelCircular = 700207,

        #endregion

        #region 常用意见
        /// <summary>
        /// 常用意见
        /// </summary>
        [Display(GroupName = "辅助功能",Name = "常用意见",Description ="常用意见")]
        CommonOpinion = 700300,
        /// <summary>
        /// 常用意见列表
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "常用意见列表", Description = "常用意见列表")]
        QueryOpenCommonOpinionList = 700301,
        /// <summary>
        /// 修改意见
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "修改意见", Description = "修改意见")]
        CommonModify = 700302,
        #endregion

        #region 工单词库
        /// <summary>
        /// 工单词库
        /// </summary>
        [Display(GroupName = "辅助功能",Name = "工单词库",Description = "工单词库")]
        OrderWord = 700400,

        /// <summary>
        /// 工单词库列表
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "工单词库列表", Description = "工单词库列表")]
		OrderWordList = 700401,

		/// <summary>
		/// 新增工单词库
		/// </summary>
		[Display(GroupName = "辅助功能", Name = "新增工单词库", Description = "新增工单词库")]
		AddOrderWord = 700402,

		/// <summary>
		/// 删除工单词库
		/// </summary>
		[Display(GroupName = "辅助功能", Name = "删除工单词库", Description = "删除工单词库")]
		DeleteOrderWord = 700403,

		/// <summary>
		/// 修改工单词库
		/// </summary>
		[Display(GroupName = "辅助功能", Name = "修改工单词库", Description = "修改工单词库")]
		UpdateOrderWord = 700404,


        #endregion

        #region 知识库词库
        /// <summary>
        /// 知识库词库
        /// </summary>
        [Display(GroupName = "辅助功能",Name = "知识库词库",Description = "知识库词库")]
        KnowledgeWord = 700500,

        /// <summary>
        /// 知识库词库列表
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "知识库词库列表", Description = "知识库词库列表")]
        KnowledgeWordList = 700501,

        /// <summary>
        /// 新增知识库词库
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "新增知识库词库", Description = "新增知识库词库")]
        AddKnowledgeWord = 700502,

        /// <summary>
        /// 删除知识库词库
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "删除知识库词库", Description = "删除知识库词库")]
        DeleteKnowledgeWord = 700503,

        /// <summary>
        /// 修改知识库词库
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "修改知识库词库", Description = "修改知识库词库")]
        UpdateKnowledgeWord = 700504,

        #endregion

        #region 区域管理
        [Display(GroupName = "辅助功能")]
        Area = 700600,
        /// <summary>
        /// 新增区域
        /// </summary>
        [Display(GroupName = "系统设置", Name = "新增区域", Description = "新增区域")]
        AddArea = 700601,
        /// <summary>
        /// 修改区域
        /// </summary>
        [Display(GroupName = "系统设置", Name = "修改区域", Description = "修改区域")]
        ModifyArea = 700602,
        /// <summary>
        /// 删除区域
        /// </summary>
        [Display(GroupName = "系统设置", Name = "删除区域", Description = "删除区域")]
        DelArea = 700603,
        /// <summary>
        /// 获取区域
        /// </summary>
        [Display(GroupName = "系统设置", Name = "获取区域", Description = "获取区域")]
        GetArea = 700604,
        #endregion

        #region 标签管理
        /// <summary>
        /// 标签管理
        /// </summary>
        [Display(GroupName = "辅助功能",Name = "标签管理",Description ="标签管理")]
        BusinessTag = 700700,
        /// <summary>
        /// 标签列表
        /// </summary>
        [Display(GroupName = "辅助功能",Name = "标签列表",Description = "标签列表")]
        BusinessTagList = 700701,
        /// <summary>
        /// 新增标签
        /// </summary>
        [Display(GroupName = "辅助功能",Name ="新增标签",Description ="新增标签")]
        AddBusinessTag = 700702,
        /// <summary>
        /// 删除标签
        /// </summary>
        [Display(GroupName ="辅助功能",Name ="删除标签",Description ="删除标签")]
        DeleteBusinessTag = 700703,
        /// <summary>
        /// 修改标签
        /// </summary>
        [Display(GroupName ="辅助功能",Name ="修改标签",Description ="修改标签")]
        UpdateBusinessTag = 700704,
        /// <summary>
        /// 获取标签实体
        /// </summary>
        [Display(GroupName ="辅助功能",Name = "获取标签实体", Description ="获取标签实体")]
        BusinessTagEntity = 700705,
        /// <summary>
        /// 标签绑定
        /// </summary>
        [Display(GroupName ="辅助功能",Name ="标签绑定",Description ="标签绑定")]
        BusinessTagBinding = 700706,
        #endregion

        #region 短信中心
        /// <summary>
        /// 短信中心
        /// </summary>
        [Display(GroupName = "辅助功能",Name ="短信中心",Description ="短信中心")]
        PushMessage = 700800,
        /// <summary>
        /// 短信列表
        /// </summary>
        [Display(GroupName ="辅助功能",Name ="短信列表",Description ="短信列表")]
        AllMessage  = 700801,
        /// <summary>
        /// 重新发送
        /// </summary>
        [Display(GroupName = "辅助功能",Name ="重新发送",Description ="重新发送")]
        SendAgain = 700802,
        #endregion

        #region 事件分类管理
        /// <summary>
        /// 事件分类管理
        /// </summary>
        [Display(GroupName ="辅助功能",Name ="事件分类管理",Description = "事件分类管理")]
        EventClassManage = 700900,
        /// <summary>
        /// 新增事件
        /// </summary>
        [Display(GroupName ="辅助功能",Name ="新增事件",Description ="新增事件")]
        AddEvent = 700901,
        /// <summary>
        /// 删除事件
        /// </summary>
        [Display(GroupName ="辅助功能",Name ="删除事件",Description ="删除事件")]
        DelEvent = 700902,
        /// <summary>
        /// 修改事件
        /// </summary>
        [Display(GroupName ="辅助工单",Name ="修改事件",Description ="修改事件")]
        ModifyEvent = 700903,
        #endregion

        #region 短信模板
        /// <summary>
        /// 短信模板
        /// </summary>
        [Display(GroupName = "辅助功能",Name ="短信模板",Description ="短信模板")]
        MsgTemplateList = 701000,
        /// <summary>
        /// 新增短信模板
        /// </summary>
        [Display(GroupName ="辅助功能",Name ="新增短信模板",Description ="新增短信模板")]
        AddMsgTemplate = 701001,
        /// <summary>
        /// 编辑短信模板
        /// </summary>
        [Display(GroupName = "辅助功能",Name ="编辑短信模板",Description ="编辑短信模板")]
        EditMsgTemplate = 701002,
        #endregion

        #region 数据导入
        /// <summary>
        /// 数据导入
        /// </summary>
        [Display(GroupName ="辅助功能",Name ="数据导入",Description ="数据导入")]
        DataOrderImport = 701100,

        #endregion

        #region 市民画像管理
        /// <summary>
        /// 市民画像管理
        /// </summary>
        [Display(GroupName = "市民画像管理", Name = "市民画像管理", Description = "市民画像管理")]
        Citizen = 701200,

        /// <summary>
		/// 市民信息列表
		/// </summary>
		[Display(GroupName = "市民画像管理", Name = "市民信息列表", Description = "市民信息列表")]
        CitizenList = 701201,

        /// <summary>
        /// 新增市民信息
        /// </summary>
        [Display(GroupName = "市民画像管理", Name = "新增市民信息", Description = "新增市民信息")]
        AddCitizen = 701202,

        /// <summary>
        /// 删除市民信息
        /// </summary>
        [Display(GroupName = "市民画像管理", Name = "删除市民信息", Description = "删除市民信息")]
        DeleteCitizen = 701203,

        /// <summary>
        /// 修改市民信息
        /// </summary>
        [Display(GroupName = "市民画像管理", Name = "修改市民信息", Description = "修改市民信息")]
        UpdateCitizen = 701204,

        /// <summary>
        /// 市民画像标签记录
        /// </summary>
        [Display(GroupName = "市民画像管理", Name = "市民画像标签记录", Description = "市民画像标签记录")]
        CitizenTag = 701205,

        #endregion

        #region 外部市民管理
        /// <summary>
        /// 外部市民管理
        /// </summary>
        [Display(GroupName = "外部市民管理",Name ="外部市民管理",Description ="外部市民管理")]
        ExtemaiCitzen  = 701300,
        /// <summary>
        /// 外部市民导入
        /// </summary>
        [Display(GroupName ="外部市民管理",Name ="外部市民导入",Description ="外部市民导入")]
        ExtemaiCitzenImport = 701301,
        /// <summary>
        /// 模板下载
        /// </summary>
        [Display(GroupName ="外部市民管理",Name ="模板下载",Description ="模板下载")]
        ExtemaiCitzenTemplateDown = 701302,

        /// <summary>
        /// 外部市民修改
        /// </summary>
        [Display(GroupName ="外部市民管理",Name ="外部市民修改",Description ="外部市民修改")]
        ExtemaiCitzenModify = 701303,
        /// <summary>
        /// 外部市民删除
        /// </summary>
        [Display(GroupName ="外部市民管理",Name ="外部市民删除",Description ="外部市民删除")]
        ExtemaiCitzenDel = 701304,

        #endregion

        #region 短信任务
        /// <summary>
        /// 短信任务
        /// </summary>
        [Display(GroupName ="短信任务",Name ="短信任务",Description ="短信任务")]
        SmsTask = 701400,
        /// <summary>
        /// 创建任务
        /// </summary>
        [Display(GroupName ="短信任务",Name ="创建任务",Description = "创建任务")]
        CreateSmsTask = 701401,
        /// <summary>
        /// 终止任务
        /// </summary>
        [Display(GroupName ="短信任务",Name ="终止任务",Description ="终止任务")]
        StopSmsTask = 701402,

        #endregion

        #region 智能外呼任务
        /// <summary>
        /// 智能外呼任务
        /// </summary>
        [Display(GroupName ="智能外呼任务",Name ="智能外呼任务",Description ="智能外呼任务")]
        AiCallOut = 701500,
        #region 外呼模板配置
        /// <summary>
        /// 外呼模板配置
        /// </summary>
        [Display(GroupName ="外呼模板配置",Name ="外呼模板配置",Description ="外呼模板配置")]
        CallOutTemplate = 701501,
        /// <summary>
        /// 新增外呼模板
        /// </summary>
        [Display(GroupName ="外呼模板配置",Name ="新增外呼模板",Description ="新增外呼模板")]
        AddCallOutTemplate = 701502,
        /// <summary>
        /// 编辑外呼模板
        /// </summary>
        [Display(GroupName ="外呼模板配置",Name ="编辑外呼模板",Description ="编辑外呼模板")]
        EditCallOutTemplate = 701503,
        /// <summary>
        /// 删除外呼模板
        /// </summary>
        [Display(GroupName ="外呼模板配置",Name ="删除外呼模板",Description ="删除外呼模板")]
        DelCallOutTemplate = 701504,
        #endregion

        #region 智能外呼任务
        /// <summary>
        /// 智能外呼任务
        /// </summary>
        [Display(GroupName ="智能外呼任务",Name ="智能外呼任务",Description ="智能外呼任务")]
        AiCallOutTask = 701505,
        /// <summary>
        /// 智能外呼任务
        /// </summary>
        [Display(GroupName ="智能外呼任务",Name = "创建任务", Description = "创建任务")]
        CreateAiCallOutTask = 701506,
        /// <summary>
        /// 创建任务
        /// </summary>
        [Display(GroupName ="智能外呼任务",Name ="终止任务",Description = "终止任务")]
        StopAiCallOutTask = 701507,
        /// <summary>
        /// 启动任务
        /// </summary>
        [Display(GroupName ="智能外呼任务",Name ="启动任务",Description ="启动任务")]
        StartAiCallOutTask = 701508,
        /// <summary>
        /// 暂停任务
        /// </summary>
        [Display(GroupName ="智能外呼任务",Name ="暂停任务",Description ="暂停任务")]
        PauseAiCallOutTask = 701509,
        #endregion
        #endregion

        
        #endregion

        #region 话务管理（80,00,00）
        /// <summary>
        /// 话务管理
        /// </summary>
        [Display(GroupName = "话务管理",Name = "话务管理",Description = "话务管理")]
        Call = 800000,
        #region 通讯记录
        /// <summary>
        /// 通讯记录
        /// </summary>
        [Display(GroupName ="话务管理",Name = "通讯记录",Description ="通讯记录")]
        CallLog = 800100,
        /// <summary>
        /// 关联业务
        /// </summary>
        [Display(GroupName ="话务管理",Name ="关联业务",Description ="关联业务")]
        LinkCall = 800101,
        /// <summary>
        /// 失联工单
        /// </summary>
        [Display(GroupName ="话务管理",Name ="失联工单",Description ="失联工单")]
        NoLinkCall = 800102,
        /// <summary>
        /// 录音转写（批量）
        /// </summary>
        [Display(GroupName = "话务管理",Name ="录音转写（批量）",Description ="录音转写（批量）")]
        RecordingTranscribed = 800103,
        /// <summary>
        /// 转工单
        /// </summary>
        [Display(GroupName ="话务管理",Name ="转工单",Description ="转工单")]
        ConvertToOrder = 800104,
        #endregion

        #region 黑白名单

        /// <summary>
        /// 黑白名单
        /// </summary>
        [Display(GroupName = "话务管理",Name ="黑白名单",Description ="黑白名单")]
        BlackList = 800200,
        /// <summary>
        /// 分页查询黑名单
        /// </summary>
        [Display(GroupName = "黑名单管理", Name = "分页查询黑名单", Description = "分页查询黑名单")]
        QueryPagedBlack = 800201,
        /// <summary>
        /// 添加电话号至黑名单
        /// </summary>
        [Display(GroupName = "黑名单管理", Name = "添加电话号至黑名单", Description = "添加电话号至黑名单")]
        AddBlackList = 800202,
        /// <summary>
        /// 删除黑名单数据
        /// </summary>
        [Display(GroupName = "黑名单管理", Name = "删除黑名单数据", Description = "删除黑名单数据")]
        RemoveBlacklist = 800203,
        #endregion

        #region 分机管理
        /// <summary>
        /// 分级管理
        /// </summary>
        [Display(GroupName ="话务管理",Name ="分机管理",Description ="分级管理")]
        TelManage = 800300,
        /// <summary>
        /// 监听分机
        /// </summary>
        [Display(GroupName ="话务管理",Name ="监听分机",Description ="监听分机")]
        ListenInTel = 800301,
        /// <summary>
        /// 强制下线
        /// </summary>
        [Display(GroupName ="话务管理",Name ="强制下线",Description ="强制下线")]
        ForceOffDuty = 800302,
        #endregion

        #region 智能应答录音
        /// <summary>
        /// 智能应答录音
        /// </summary>
        [Display(GroupName = "话务管理", Name ="智能应答录音",Description ="智能应答录音")]
        TelSmartRecord = 800400,

        #endregion

        #endregion

        #region 智能化管理（90,00,00）
        /// <summary>
        /// 智能化
        /// </summary>
        [Display(GroupName = "智能化",Name ="智能化",Description = "智能化")]
        Intellect  = 900000,

        #region 智能化语音导航
        /// <summary>
        /// 智能化语音导航
        /// </summary>
        [Display(GroupName = "智能化",Name ="智能化语音导航",Description ="智能化语音导航")]
        IntellectIvr = 900100,
        #endregion
        #region 智能质检
        /// <summary>
        /// 智能质检
        /// </summary>
        [Display(GroupName = "智能化",Name ="智能质检",Description ="智能质检")]
        IntellectQuality = 900200,
        #endregion
        #region 智能回访
        /// <summary>
        /// 智能回访
        /// </summary>
        [Display(GroupName = "智能化",Name ="智能回访",Description ="智能回访")]
        IntellectVisit = 900300,
        #endregion

        #endregion

        #region 数据统计（11,00,00）
        /// <summary>
        /// 数据统计
        /// </summary>
        [Display(GroupName = "数据统计",Name ="数据统计",Description ="数据统计")]
        DataCanter = 110000,

        #region 大屏数据 (11,04,00)
        /// <summary>
        /// 数据大屏
        /// </summary>
        [Display(GroupName = "大屏管理", Name = "数据大屏", Description = "数据大屏")]
        ScreenManage = 110400,
        /// <summary>
        /// 坐席监控
        /// </summary>
        [Display(GroupName = "大屏管理", Name = "坐席监控", Description = "坐席监控")]
        SeatMonitor = 110401,
        /// <summary>
        /// 数据大屏
        /// </summary>
        [Display(GroupName = "大屏管理", Name = "数据大屏", Description = "数据大屏")]
        ScreenData = 110402,
        #endregion

        #region 话务统计（11,01,00）
        /// <summary>
        /// 话务统计
        /// </summary>
        [Display(GroupName = "数据统计",Name ="话务统计",Description ="话务统计")]
        CallStatistics = 110100,
        /// <summary>
        /// 话务统计分析
        /// </summary>
        [Display(GroupName = "数据统计",Name = "话务统计分析",Description ="话务统计分析")]
        CallStatisticsAnalysis = 110101,
        /// <summary>
        /// 坐席话务统计分析
        /// </summary>
        [Display(GroupName = "数据统计",Name = "坐席话务统计分析",Description ="坐席话务统计分析")]
        SeatCallStatisticsAnalysis = 110102,
        /// <summary>
        /// 话机动作统计
        /// </summary>
        [Display(GroupName = "数据统计",Name = "话机动作统计",Description = "话机动作统计")]
        TelActStatistics = 110103,
        /// <summary>
        /// 转外线统计分析
        /// </summary>
        [Display(GroupName ="数据统计",Name = "转外线统计分析",Description ="转外线统计分析")]
        TelOutStatistics = 110104,
        /// <summary>
        /// 坐席小休统计表
        /// </summary>
        [Display(GroupName ="数据统计",Name ="坐席小休统计表",Description ="坐席小休统计表")]
        SeatRestStatistics = 110105,
        /// <summary>
        /// 通话时段统计
        /// </summary>
        [Display(GroupName ="数据统计",Name ="通话时段统计",Description ="通话时段统计")]
        HourCallStatistics = 110106,
        /// <summary>
        /// 热线号码统计
        /// </summary>
        [Display(GroupName ="数据统计",Name ="热线号码统计",Description ="热线号码统计")]
        HotLineNumStatistics = 110107,
        /// <summary>
        /// 坐席动作类型统计
        /// </summary>
        [Display(GroupName ="数据统计",Name ="坐席动作类型统计",Description ="坐席动作类型统计")]
        SeatActionTypeStatistics = 110108,
        #endregion

        #region 业务统计（11,02,00）
        /// <summary>
        /// 工单统计
        /// </summary>
        [Display(GroupName = "数据统计",Name = "工单统计",Description ="工单统计")]
        OrderStatistics = 110200,
        /// <summary>
        /// 话务员办件统计
        /// </summary>
        [Display(GroupName = "数据统计",Name = "话务员办件统计",Description = "话务员办件统计")]
        CenterStatistics = 110201,
        
        /// <summary>
        /// 回访不满意原因统计
        /// </summary>
        [Display(GroupName ="数据统计",Name = "回访不满意原因统计",Description ="回访不满意原因统计")]
        VisitNoSatisfiedReasonStatistics = 110204,
        /// <summary>
        /// 不满意回访明细
        /// </summary>
        [Display(GroupName = "数据统计",Name = "不满意回访明细",Description ="不满意回访明细")]
        VisitNoSatisfiedDetailStatistics = 110205,
        /// <summary>
        /// 特提统计
        /// </summary>
        [Display(GroupName = "数据统计",Name ="特提统计",Description ="特提统计")]
        SpecialRetrieveStatistics = 110206,
        /// <summary>
        /// 特提统计明细
        /// </summary>
        [Display(GroupName ="数据统计",Name ="特提统计明细",Description ="特提统计明细")]
        SpecialRetrieveDetailStatistics = 110207,
        /// <summary>
        /// 热点类型统计
        /// </summary>
        [Display(GroupName = "数据统计",Name ="热点类型统计",Description ="热点类型统计")]
        HotSpotStatistics = 110208,
        /// <summary>
        /// 热点类型部门统计
        /// </summary>
        [Display(GroupName ="数据统计",Name ="热点类型部门统计",Description ="热点类型部门统计")]
        HotSpotOrgStatistics = 110209,
        /// <summary>
        /// 受理量前10
        /// </summary>
        [Display(GroupName ="数据统计",Name ="受理量前10",Description = "受理量前10")]
        OrderStartCountTopTen = 110210,
        /// <summary>
        /// 回访量统计
        /// </summary>
        [Display(GroupName ="数据统计",Name ="回访量统计",Description ="回访量统计")]
        VisitOrderStatistics = 110211,
        /// <summary>
        /// 热点类型小类统计
        /// </summary>
        [Display(GroupName ="数据统计",Name ="热点类型小类统计",Description ="热点类型小类统计")]
        HotSpotSubclassStatistics = 110212,
        /// <summary>
        /// 部门受理类型统计周期
        /// </summary>
        [Display(GroupName ="数据统计",Name ="部门受理类型统计周期",Description ="部门受理类型统计周期")]
        OrgAcceptTypeStatistics = 110213,
        /// <summary>
        /// 派单量统计
        /// </summary>
        [Display(GroupName ="数据统计",Name ="派单量统计",Description ="派单量统计")]
        DispatchQuantityStatistics = 110214,
        /// <summary>
        /// 信件来源统计
        /// </summary>
        [Display(GroupName ="数据统计",Name ="信件来源统计",Description ="信件来源统计")]
        OrderSourceStatistics = 110215,
        /// <summary>
        /// 信件来源分时统计
        /// </summary>
        [Display(GroupName ="数据统计",Name ="信件来源分时统计",Description ="信件来源分时统计")]
        OrderSourceTimeStatistics = 110216,
        /// <summary>
        /// 受理类型时分统计
        /// </summary>
        [Display(GroupName ="数据统计",Name = "受理类型分时统计", Description = "受理类型分时统计")]
        AcceptTypeTimeStatistics = 110217,
        /// <summary>
        /// 热点类型分时统计
        /// </summary>
        [Display(GroupName ="数据统计",Name ="热点类型分时统计",Description = "热点类型分时统计")]
        HotspotTypeTimeStatistics = 110218,
        /// <summary>
        /// 区域分时统计
        /// </summary>
        [Display(GroupName ="数据统计",Name ="区域分时统计",Description ="区域分时统计")]
        AreaTimeStatistics = 110219,
        /// <summary>
        /// 受理类型统计
        /// </summary>
        [Display(GroupName ="数据统计",Name ="受理类型统计",Description ="受理类型统计")]
        AcceptTypeStatistics = 110220,
        /// <summary>
        /// 下级区域统计
        /// </summary>
        [Display(GroupName ="数据统计",Name ="下级区域统计",Description ="下级区域统计")]
        NextLevelAreaStatistics = 110221,
        /// <summary>
        /// 热点区域统计
        /// </summary>
        [Display(GroupName ="数据统计",Name ="热点区域统计",Description ="热点区域统计")]
        HotspotAndAreaStatistics = 110222,
        /// <summary>
        /// 热点满意度统计
        /// </summary>
        [Display(GroupName ="数据统计",Name ="热点满意度统计",Description ="热点满意度统计")]
        HotspotSatisfiedStatistics = 110223,
        /// <summary>
        /// 热点受理类型统计
        /// </summary>
        [Display(GroupName = "数据统计", Name = "热点受理类型统计", Description = "热点受理类型统计")]
        HotspotAcceptTypeStatistics = 110234,
        #endregion

        #region 知识库统计（11,03,00）
        /// <summary>
        /// 知识库统计
        /// </summary>
        [Display(GroupName = "数据统计",Name ="知识库统计",Description ="知识库统计")]
        KnowledgeStatistics = 110300,
        /// <summary>
        /// 知识库数据统计
        /// </summary>
        [Display(GroupName ="数据统计",Name ="知识库数据统计",Description ="知识库数据统计")]
        KnowledgeDataStatistics = 110301,
        #endregion

        #region  中心办件统计（11,05,00）
        /// <summary>
        /// 中心办件统计
        /// </summary>
        [Display(GroupName ="数据统计",Name ="中心办件统计",Description ="中心办件统计")]
        CallCenterAccpetStatistics = 110500,
        /// <summary>
        /// 中心统计报表
        /// </summary>
        [Display(GroupName ="中心办件统计",Name ="中心统计报表",Description ="中心统计报表")]
        CallCenterStatistics = 110501,
        /// <summary>
        /// 高频事项预警
        /// </summary>
        [Display(GroupName ="中心办件统计",Name ="高频事项预警",Description ="高频事项预警")]
        FrequentlyEvent = 110502,

        /// <summary>
        /// 高频来电统计
        /// </summary>
        [Display(GroupName ="中心办件统计",Name ="高频来电统计",Description ="高频来电统计")]
        FrequentlyTel = 110503,

        /// <summary>
        /// 市州互转信息列表
        /// </summary>
        [Display(GroupName ="中心办件统计",Name ="市州互转信息列表",Description ="市州互转信息列表")]
        TransferCity = 110504,
        /// <summary>
        /// 回退错件统计
        /// </summary>
        [Display(GroupName = "中心办件统计", Name = "回退错件统计", Description = "回退错件统计")]
        WrongItemOrder = 110505,
        /// <summary>
        /// 应急清单
        /// </summary>
        [Display(GroupName = "中心办件统计", Name = "应急清单", Description = "应急清单")]
        EmergencyList = 110506,
        /// <summary>
        /// 中心受理统计
        /// </summary>
        [Display(GroupName ="中心办件统计",Name ="中心受理统计",Description ="中心受理统计")]
        CenterAcceptStatistics = 110507,
        /// <summary>
        /// 报告管理
        /// </summary>
        [Display(GroupName ="中心办件统计",Name ="报告管理",Description ="报告管理")]
        ReportManage = 110508,
        /// <summary>
        /// 数据清单
        /// </summary>
        [Display(GroupName ="中心办件统计",Name ="数据清单",Description ="数据清单")]
        OrderDataList = 110509,
        /// <summary>
        /// 提起甄别统计
        /// </summary>
        [Display(GroupName ="中心办结统计",Name ="提起甄别统计",Description ="提起甄别统计")]
        AddOrderScreenStatistics = 110510,
        /// <summary>
        /// 提起甄别审核统计
        /// </summary>
        [Display(GroupName ="中心办件统计",Name ="提起甄别审核统计",Description ="提起甄别审核统计")]
        AddOrderScreenApproveStatistics = 110511,
        /// <summary>
        /// 未签收统计
        /// </summary>
        [Display(GroupName ="中心办件统计",Name ="未签收统计",Description ="未签收统计")]
        NoSignStatistics = 110512,
        /// <summary>
        /// 回访来源统计
        /// </summary>
        [Display(GroupName ="中心办件统计",Name ="回访来源统计",Description ="回访来源统计")]
        VisitSourceStatistics = 110513,
        /// <summary>
        /// 企业专席信件统计
        /// </summary>
        [Display(GroupName ="中心办件统计",Name ="企业专席信件统计",Description ="企业专席信件统计")]
        EnterpriseSeatOrderStatistics = 110514,
        /// <summary>
        /// 发布量统计
        /// </summary>
        [Display(GroupName ="中心办件统计",Name ="发布量统计",Description ="发布量统计")]
        PublishCountStatistics = 110515,
        /// <summary>
        /// 扭转信件统计
        /// </summary>
        [Display(GroupName ="中心办件统计",Name ="扭转信件统计",Description ="扭转信件统计")]
        VisitJudeStatistics = 110516,
        #endregion

        #region 部门办件统计（11,06,00）
        /// <summary>
        /// 部门办件统计
        /// </summary>
        [Display(GroupName ="数据统计",Name ="部门办件统计",Description ="部门办件统计")]
        OrgAcceptStatistics = 110600,

        /// <summary>
        /// 部门办件统计表
        /// </summary>
        [Display(GroupName ="数据统计",Name = "部门办件统计表", Description ="部门办件统计表")]
        OrgOrderStatistics = 110601,

        /// <summary>
        /// 部门超期统计
        /// </summary>
        [Display(GroupName = "数据统计", Name = "部门超期统计", Description = "部门超期统计")]
        OrgOverdueStatistics = 110602,

        /// <summary>
        /// 部门延期统计
        /// </summary>
        [Display(GroupName = "数据统计", Name = "部门延期统计", Description = "部门延期统计")]
        OrgDelayStatistics = 110603,
        /// <summary>
        /// 部门满意度统计
        /// </summary>
        [Display(GroupName ="数据统计",Name = "部门满意度统计",Description = "部门满意度统计")]
        VisitAndOrgSatisfactionStatistics = 110604,

        /// <summary>
        /// 二次办理统计
        /// </summary>
        [Display(GroupName = "数据统计", Name = "二次办理统计", Description = "二次办理统计")]
        SecondHandleStatistics = 110605,
        /// <summary>
        /// 二次办理满意度
        /// </summary>
        [Display(GroupName = "数据统计", Name = "二次办理满意度", Description = "二次办理满意度")]
        SecondHandleSatisfied = 110606,
        /// <summary>
        /// 部门未签收统计
        /// </summary>
        [Display(GroupName ="数据统计",Name ="部门未签收统计",Description ="部门未签收统计")]
        OrgUnSignedSatisfied = 110607,


        #endregion


        #endregion

        #region 司法行政行政监督管理(12,00,00)
        /// <summary>
        /// 司法行政行政监督管理
        /// </summary>
        [Display(GroupName = "司法行政行政监督管理",Name = "司法行政行政监督管理",Description = "司法行政行政监督管理")]
        SiFaManage = 120000,

        #region 司法工单中心
        /// <summary>
        /// 司法工单中心
        /// </summary>
        [Display(GroupName = "司法行政行政监督管理",Name ="司法工单中心",Description ="司法工单中心")]
        SiFaOrderCenter = 120100,

        /// <summary>
        /// 线索核实
        /// </summary>
        [Display(GroupName = "司法行政行政监督管理",Name ="线索核实",Description ="线索核实")]
        SiFaOrderVerify  = 120101,
        /// <summary>
        /// 线索核实（批量）
        /// </summary>
        [Display(GroupName ="司法行政行政监督管理",Name ="线索核实（批量）",Description ="线索核实（批量）")]
        SiFaOrderBatichVerify = 120102,
        #endregion

        #region 司法数据统计
        /// <summary>
        /// 司法数据统计
        /// </summary>
        [Display(GroupName = "司法行政行政监督管理",Name ="数据统计",Description ="司法数据统计")]
        SiFaDataStatistics = 120200,
        /// <summary>
        /// 事件分类统计
        /// </summary>
        [Display(GroupName ="司法数据统计",Name ="事件分类统计",Description ="事件分类统计")]
        SiFaEventClassStatistics = 120201,
        /// <summary>
        /// 执法部门办件统计
        /// </summary>
        [Display(GroupName ="司法数据统计",Name ="执法部门办件统计",Description ="执法部门办件统计")]
        SiFaEnforcementOrgHandleStatistics = 120202,
        /// <summary>
        /// 区域分类统计
        /// </summary>
        [Display(GroupName ="司法数据统计",Name ="区域分类统计",Description ="区域分类统计")]
        SiFaAreaClassStatistics = 120203,
        /// <summary>
        /// 数据大屏
        /// </summary>
        [Display(GroupName ="司法数据统计",Name ="数据大屏",Description ="数据大屏")]
        SiFaScreenData = 120204,
        /// <summary>
        /// 部门办件满意度
        /// </summary>
        [Display(GroupName ="司法数据统计",Name ="部门办件满意度",Description ="部门办件满意度")]
        SiFaOrgVisitAndOrgSatisfactionStatistics = 120205,
        #endregion

        #region 自定义工单
        /// <summary>
        /// 自定义工单
        /// </summary>
        [Display(GroupName ="司法自定义工单",Name ="自定义工单",Description ="自定义工单")]
        SiFaCustomOrder = 120300,
        /// <summary>
        /// 新建工单
        /// </summary>
        [Display(GroupName ="司法自定义工单",Name ="新建工单",Description ="新建工单")]
        SiFaNewOrder = 120301,

        #endregion

        #endregion

        #region 数据共享平台(13,00,00)
        /// <summary>
        /// 数据共享平台
        /// </summary>
        [Display(GroupName ="数据共享平台",Name ="数据共享平台",Description ="数据共享平台")]
        DataSharing = 130000,
        /// <summary>
        /// 平台配置
        /// </summary>
        [Display(GroupName ="数据共享平台",Name ="平台配置",Description ="平台配置")]
        PlatformConfig = 130100,
        /// <summary>
        /// 推送任务
        /// </summary>
        [Display(GroupName = "数据共享平台", Name ="推送任务",Description = "推送任务")]
        PushTask = 130200,
        /// <summary>
        /// 工单及时推送
        /// </summary>
        [Display(GroupName ="数据共享平台",Name ="工单及时推送",Description ="工单及时推送")]
        OrderTimelyPush = 130300,
        /// <summary>
        /// 通话记录及时上传
        /// </summary>
        [Display(GroupName ="数据共享平台",Name ="通话记录及时上传",Description ="通话记录及时上传")]
        CallRecordTimelyPush = 130400,
        /// <summary>
        /// 无通话记录工单
        /// </summary>
        [Display(GroupName ="数据共享平台",Name ="无通话记录工单",Description = "无通话记录工单")]
        HasNotCallRecordOrder = 130500,
        /// <summary>
        /// 及时率
        /// </summary>
        [Display(GroupName ="数据共享平台",Name ="及时率",Description ="及时率")]
        TimelinessRate = 130600,
        /// <summary>
        /// 期满时间修改
        /// </summary>
        [Display(GroupName ="数据共享平台",Name ="期满时间修改",Description ="期满时间修改")]
        ExpirationTimeEdit = 130700,
        /// <summary>
        /// 对接平台用户管理
        /// </summary>
        [Display(GroupName ="数据共享平台",Name ="对接平台用户管理",Description ="对接平台用户管理")]
        DockingPlatUserManage = 130800,
        /// <summary>
        /// 待推送数据（新）
        /// </summary>
        [Display(GroupName ="数据共享平台",Name ="待推送数据（新）",Description ="待推送数据（新）")]
        PushDataNew = 130900,
        /// <summary>
        /// 已推送任务（新）
        /// </summary>
        [Display(GroupName ="数据共享平台",Name ="已推送任务（新）",Description ="已推送任务（新）")]
        PushedDataNew = 131000,
        /// <summary>
        /// 工单及时上传(新)
        /// </summary>
        [Display(GroupName = "数据共享平台", Name = "工单及时上传(新)", Description = "工单及时上传(新)")]
        OrderTimelyPushNew = 131100,
        /// <summary>
        /// 无通话记录工单(新)
        /// </summary>
        [Display(GroupName = "数据共享平台", Name = "无通话记录工单(新)", Description = "无通话记录工单(新)")]
        HasNotCallRecordOrderNew = 131200,
        /// <summary>
        /// 及时率(新)
        /// </summary>
        [Display(GroupName = "数据共享平台", Name = "及时率(新)", Description = "及时率(新)")]
        TimelinessRateNew = 131300,
        /// <summary>
        /// 推送失败查询
        /// </summary>
        [Display(GroupName ="数据共享平台",Name = "推送失败查询",Description ="推送失败查询")]
        PublishErrorQuery = 131400,
        /// <summary>
        /// 其他平台数据接收
        /// </summary>
        [Display(GroupName ="数据共享平台",Name ="其他平台数据接收",Description ="其他平台数据接收")]
        OtherPlatDataAccept = 131500,
        #endregion

        #region 省平台对接(14,00,00)
        /// <summary>
        /// 省平台对接
        /// </summary>
        [Display(GroupName = "省平台对接", Name = "省平台对接", Description = "省平台对接")]
        ProvinceAbutment = 140000,
        #region 省综合查询
        /// <summary>
        /// 省综合查询
        /// </summary>
        [Display(GroupName ="省平台对接",Name ="省综合查询",Description ="省综合查询")]
        ProvinceOrderList = 140100,
        /// <summary>
        /// 省工单退回
        /// </summary>
        [Display(GroupName = "省平台对接", Name = "省工单退回", Description = "省工单退回")]
        ProvinceSendBack = 140101,
        #endregion
        /// <summary>
        /// 省延期查询
        /// </summary>
        [Display(GroupName ="省平台对接",Name ="省延期查询",Description ="省延期查询")]
        ProvinceOrderDelay = 140200,
        /// <summary>
        /// 省退单查询
        /// </summary>
        [Display(GroupName ="省平台对接",Name ="省退单查询",Description ="省退单查询")]
        ProvinceOrderReturn = 140300,
        /// <summary>
        /// 省甄别查询
        /// </summary>
        [Display(GroupName ="省平台对接",Name ="省甄别查询",Description ="省甄别查询")]
        ProvinceOrderOrderScreen = 140400,
        /// <summary>
        /// 政民互动发布
        /// </summary>
        [Display(GroupName = "省平台对接", Name = "政民互动发布", Description = "政民互动发布")]
        GovernmentpPeopleInteractPublish = 140500,

        #endregion

        #region 公用（99，00,00）

        #region 话机操作面板权限
        /// <summary>
        /// 通知阅读
        /// </summary>
        [Display(GroupName = "公用",Name ="通知阅读",Description ="通知阅读")]
        Readed = 990101,

        /// <summary>
        /// 录音下载
        /// </summary>
        [Display(GroupName ="公用",Name = "录音下载", Description ="录音下载")]
        RecordDownload = 990102,
        /// <summary>
        /// 坐席面板
        /// </summary>
        [Display(GroupName = "公用", Name = "坐席面板", Description = "坐席面板")]
        TelPanel = 990103,


       

        #endregion
        
        #endregion

	}
}